-------------------------------------------------------------------------------
-- Soulburn.mcr
-- MacroScripts File
-- By Neil Blevins (neil@soulburn3d.com)
-- May 13th 2000
-------------------------------------------------------------------------------

MacroScript Sym category:"Soulburn" tooltip:"Sym" Icon:#("Soulburn",1)
(
-------------------------------------------------------------------------------
-- Sym_v120.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.20
-- Created On: 09/02/99
-- Modified On: 05/01/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Takes any selected objects and instances and mirrors them across the x axis
-- in one button press. A very simple script, I wrote it primarily for people 
-- like me who are modeling cars, buildings, helicopters, whatever, and want 
-- to build everything on one side and then make frequent previews of what 
-- the model will look like with both sides (and who don't want to click on 
-- many buttons). Also allows you to delete your mirrored objects using a 
-- button once you finish your render and / or visualization preview.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 adds the ability to delete using a button your mirrored objects
-- once you finish your render and / or visualization preview.
--
-- v 1.11 Added an error box if you haven't selected an object, an error box
-- if you delete your object using delete and then press the Delete Mirrored 
-- Instance button and optimized the code a bit.
--
-- v 1.20 Removes the ability to delete the geometry made by the script. Why
-- am I removing functionality? Because I've been using the script for a year
-- now and don't use it the delete button, and it gets in the way since it's 
-- creating an unwanted window and an unwanted selection set. I commented out 
-- the code so if someone wants to reenable it, they can.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
If $ == undefined then
	(MessageBox "No Object(s) is selected" title:"Sym")
	else
	(
	instance $
	about [0,0,0] scale $ [-1,1,1]
--	selectionSets["MI"] = $
--	rollout deleteinstance "Delete Mirrored Instance"
--		( 
--		button deleteinstance "Delete Mirrored Instance"
--		on deleteinstance pressed do 
--			(
--			If selectionSets["MI"] == undefined then
--			(
--			MessageBox "Your instance has already been deleted through some other method" title:"Sym"
--			closeRolloutFloater deleteinstancefloater
--			)
--			else
--				(
--				delete selectionSets["MI"]
--				deleteItem selectionSets "MI"
--				closeRolloutFloater deleteinstancefloater
--				)
--			)
--		)
--	deleteinstancefloater = newRolloutFloater "Delete Mirrored Instance" 260 100 
--	addRollout deleteinstance deleteinstancefloater
	)
)
-------------------------------------------------------------------------------
)

MacroScript CameraMaker category:"Soulburn" tooltip:"CameraMaker" Icon:#("Soulburn",2)
(
-------------------------------------------------------------------------------
-- CameraMaker_v210.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 2.10
-- Created On: 07/31/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Takes any perspective viewport that is currently active and creates a camera
-- with the same perspective, and changes that view into the view of the 
-- camera. In short, changes your view from a perspective to a camera view in 
-- one click (without having to create a camera, select it, match it using the 
-- match to perspective function, and then switching the current view to the 
-- newly created camera.) Also works if you select a camera view to convert to 
-- a second camera view with the same perspective. Not recommended for use with
-- orthogonal views, but it still works (sorta).
--
-- Special thanks to Larry Minton for the MatchCameraToViewport function, which 
-- was used in the original algorithm.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 2.00 is a rewrite using a new algorithm based on code originally written 
-- by Andrew Marek
--
-- v 2.01 fixes a bug that caused the target to be too close to the camera
-- under certain conditions. Thanks to Scott Kirvan for some math and 
-- inspiration here.
--
-- v 2.10 Now it displays a safeframe. Also fixed a bug where the target would
-- have a wrong name. However, the camera and target name remain unlinked, 
-- unlike a camera made using conventional methods.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
focdistance = gw.GetFocalDist()
cp = mapscreentoworldray (getviewsize()/2)
ct = targetobject position:(cp.pos+(cp.dir*focdistance))

NewCamera = targetcamera pos:cp.pos target:ct isSelected:on
viewport.setCamera NewCamera

displaySafeFrames = true

camera_name = $.name
select $.target
$.name = camera_name + ".Target"
max select none 
-------------------------------------------------------------------------------
)

MacroScript TransformTools category:"Soulburn" tooltip:"TransformTools" Icon:#("Soulburn",3)
(
-------------------------------------------------------------------------------
-- TransformTools_v119.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.19
-- Created On: 09/20/99
-- Modified On: 05/08/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Lots of little useful tools to help transform things quickly. Includes the 
-- functionality of PositionCopy, SimpleRotation, and VertexdPositionCopy, 
-- + extra stuff.
--
-- PositionCopy: A helper to copy position info from one object or vertex to 
-- another. Select the object or vertex you want to copy from, hit the copy 
-- button. Then select the object or vertex you want to copy to, and hit 
-- either the x, y, z, or xyz button to paste that particular position 
-- information. xyz? prints out your currently copied xyz position. Can only
-- copy and paste vertex information to and from editable mesh objects that
-- have no modifiers added to them currently (this probably won't change 
-- till R4).
--
-- SimpleRotation: allows you to quickly rotate an object about a specified 
-- coordinate system using various popular degree increments. The R buttons
-- stand for Random. The negative / positive radiobuttons lets you choose the 
-- direction of the rotation. The axis preset buttons are some preset axis
-- around which the rotation could occur, but the rotation will always follow
-- the currently selected UI coordinate system.
--
-- Random Scale: lets you scale an object by a random amount. The min and max
-- values for the scale you choose. Remember, applying this to an object
-- again and again may cause weird results, because it scales your current
-- object, it does not scale the original object from before you hit the scale
-- button for the first time.
--
-- More...More...: The C I R buttons lets you quickly make a copy, instance, 
-- or reference of your object.
--
-- Clear: Clears the position, rotation, or scale info so the objects 
-- defaults back to no rotation, at 0,0,0 with 100% scale factors in all 
-- directions.
--
-- WARNING: This script only works if you have avg_dlx.dlx version 2.03 or higher 
-- installed. Get this file from http://www.soulburn3d.com
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Some code cleanup and added the VertexPositionCopy script 
-- functionality, so now if you select a vertex instead of an object in 
-- positioncopy, it will copy and paste vertex information. Only works 
-- currently with editable mesh objects with no higherlevel modifiers.
--
-- v 1.11 The rotation stuff now uses the currently selected UI coordinate 
-- system, and made the axis selection options presets. Special thanks to 
-- Larry Minton for providing me with his script extension pack #4 that let
-- me accomplish this task.
--
-- v 1.12 Some code cleanup and added the basics for a new feature called
-- random scale that does just that, randomly scales an object. This feature
-- will become more useful in my next revision as I add more functionality.
--
-- v 1.13 Cleaned up the interface, added a high and low value for the random 
-- scale function, added a button to see the currently copied x y z value.
--
-- v 1.14 The button to view the currently copied xyz values is now editable.
--
-- v 1.15 Now it works fine with even when you have several objects selected
-- at the same time.
--
-- v 1.16 Now gives warning messages when you try and copy or paste the vertex
-- position of a non editable mesh object, or an object with any modifiers
--
-- v 1.17 Fixes a bug that stopped rotation clearing if you only had one 
-- object selected.
--
-- v 1.18 Added version number to Titlebar.
--
-- v 1.19 Copied Position Floater now uses worldunits instead of regular units.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

negpos = 1
copiedxposition = 0.0
copiedyposition = 0.0
copiedzposition = 0.0
lowvalue = 25
highvalue = 200
iamopen = 0
theoldposition = [100,100]

-- Functions

fn pastetheobjectposition copytype xposition yposition zposition =
	(
	if copytype == 1 then $.pos.x = xposition
	if copytype == 2 then $.pos.y = yposition
	if copytype == 3 then $.pos.z = zposition
	if copytype == 4 then 
		(
		$.pos.x = xposition
		$.pos.y = yposition
		$.pos.z = zposition
		)
	)

fn pastethevertexposition copytype xposition yposition zposition =
	(
	if classof $.baseobject == Editable_mesh and $.modifiers.count == 0 then 
		(
		if $.selectedVerts.count == 0 then
		(MessageBox "No Vertex has been selected to copy to" title:"Position Copy")
		else 
		for i = 1 to $.selectedVerts.count do
			(
			currentwholeposition = getVert $ $.selectedVerts[i].index
			if copytype == 1 then 
				(
				setvert $ $.selectedVerts[i].index [xposition,currentwholeposition.y,currentwholeposition.z]
				completeRedraw()
				)
			if copytype == 2 then
				(
				setvert $ $.selectedVerts[i].index [currentwholeposition.x,yposition,currentwholeposition.z]
				completeRedraw()
				)
			if copytype == 3 then 
				(
				setvert $ $.selectedVerts[i].index [currentwholeposition.x,currentwholeposition.y,zposition]
				completeRedraw()
				)
			if copytype == 4 then 
				(
				setvert $ $.selectedVerts[i].index [xposition,yposition,zposition]
				completeRedraw()
				)
			)
		)
	else
	(MessageBox "Please collapse your stack. Vertex copy and paste only works on editable mesh objects with no modifiers in the modifier stack." title:"Position Copy")
	)

fn pasteobjectorvertex copytype xposition yposition zposition = 
	(
	If subObjectLevel == 1 then pastethevertexposition copytype xposition yposition zposition
 	else pastetheobjectposition copytype xposition yposition zposition
	)

fn amiallowedtopaste copytype xposition yposition zposition =
	(
	if $ == undefined then (MessageBox "Nothing is selected to copy to" title:"PositionCopy")
	else pasteobjectorvertex copytype xposition yposition zposition
	)

fn copyavertexposition = 
	(
	if classof $.baseobject == Editable_mesh and $.modifiers.count == 0 then 
		(
		If $.selectedVerts.count == 0 then
		(MessageBox "No Vertex has been selected to copy from" title:"Position Copy")
			else
			(
			If $.selectedVerts.count > 1 then
			(MessageBox "Please select only one vertex" title:"Position Copy")
			else
				(
				wholeposition = getVert $ $.selectedVerts[1].index
				copiedxposition = wholeposition.x
				copiedyposition = wholeposition.y
				copiedzposition = wholeposition.z
				)
			)
		)
	else
	(MessageBox "Please collapse your stack. Vertex copy and paste only works on editable mesh objects with no modifiers in the modifier stack." title:"Position Copy")
	)

fn copyanobjectposition = 
	(
	copiedxposition = $.pos.x
	copiedyposition = $.pos.y
	copiedzposition = $.pos.z
	)

fn copyobjectorvertex = 
	(
	If subObjectLevel == 1 then copyavertexposition()
	else copyanobjectposition()
	)
	
fn amiallowedtocopy = 
	(
	If $ == undefined then
	(MessageBox "No Object(s) is selected to copy from" title:"Position Copy")
	else 
		(
		if $ == $selection then
		(MessageBox "Please select only one object" title:"Position Copy")
		else copyobjectorvertex()
		)
	)

fn axisRotate obj rotation =  
	(	local axis
		local objA = if classof obj == objectSet or classof obj == array then obj else #(obj)
		if getCoordCenter() != #local then
		(	axis = getTransformAxis objA[1] 0
			for obj1 in objA do in coordsys axis about axis rotate obj1 rotation
		)
		else
		(	for obj1 in objA do
			(	axis = getTransformAxis obj1 0
				in coordsys axis about axis rotate obj1 rotation
			)
		)
	)

fn dorotation rotang rotax =
	(
	if $ == undefined then (MessageBox "Please Pick an Object" title:"SimpleRotation")
	else
		(
		axisRotate $ (angleaxis rotang rotax)
		)
	)

fn scalemyobjectrandomly typeofscale lowvalue highvalue =
	(
	if $ == undefined then (MessageBox "Please Pick an Object" title:"RandomScale")
	else
		(
		for i = 1 to selection.count do
			(
			currentx = selection[i].scale.x
			currenty = selection[i].scale.y
			currentz = selection[i].scale.z
			reallowvalue = lowvalue*0.01
			realhighvalue = highvalue*0.01
			if typeofscale == 1 then selection[i].scale.x = currentx*(random reallowvalue realhighvalue)
			if typeofscale == 2 then selection[i].scale.y = currenty*(random reallowvalue realhighvalue)
			if typeofscale == 3 then selection[i].scale.z = currentz*(random reallowvalue realhighvalue)
			if typeofscale == 4 then 
				(
				selection[i].scale.x = currentx*(random reallowvalue realhighvalue)
				selection[i].scale.y = currenty*(random reallowvalue realhighvalue)
				selection[i].scale.z = currentz*(random reallowvalue realhighvalue)
				)
			)
		)
	)

-- Rollouts

rollout copyposition "PositionCopy"
	( 
	button copypos "Copy" width:40 across:2 align:#center 
	on copypos pressed do 
		(
		amiallowedtocopy()
		if iamopen == 1 then
			(
			theoldposition = currentlycopiedvalues.pos
			closeRolloutFloater currentlycopiedvalues
			currentlycopiedvalues = newRolloutFloater "Copied Position" 130 134 theoldposition.x theoldposition.y
			addRollout thecurrentlycopiedvalues currentlycopiedvalues
			)
		else false
		)

	button displaycopiedposition "XYZ?" width:40 align:#center 
	on displaycopiedposition pressed do 
		(
		if iamopen == 1 then 
			(
			theoldposition = currentlycopiedvalues.pos
			closeRolloutFloater currentlycopiedvalues
			iamopen = 0
			)
		else
			(
			currentlycopiedvalues = newRolloutFloater "Copied Position" 130 134 theoldposition.x theoldposition.y
			addRollout thecurrentlycopiedvalues currentlycopiedvalues
			iamopen = 1
			)
		)
	
	button xposcopy "X" width:25 across:3 align:#center 
	on xposcopy pressed do amiallowedtopaste 1 copiedxposition copiedyposition copiedzposition

	button yposcopy "Y" width:25 align:#center 
	on yposcopy pressed do amiallowedtopaste 2 copiedxposition copiedyposition copiedzposition

	button zposcopy "Z" width:25 align:#center 
	on zposcopy pressed do amiallowedtopaste 3 copiedxposition copiedyposition copiedzposition

	button xyzposcopy "XYZ" width:80 align:#center 
	on xyzposcopy pressed do amiallowedtopaste 4 copiedxposition copiedyposition copiedzposition
	)

rollout thecurrentlycopiedvalues "Copied Position"
	(
	spinner currentlycopiedxvalue "X: " range:[-9999999,9999999,copiedxposition] fieldWidth:60 type:#worldunits
	on currentlycopiedxvalue changed val do copiedxposition = val

	spinner currentlycopiedyvalue "Y: " range:[-9999999,9999999,copiedyposition] fieldWidth:60 type:#worldunits
	on currentlycopiedyvalue changed val do copiedyposition = val

	spinner currentlycopiedzvalue "Z: " range:[-9999999,9999999,copiedzposition] fieldWidth:60 type:#worldunits
	on currentlycopiedzvalue changed val do copiedzposition = val
	)

rollout simplerotation "SimpleRotation"
	(
	label axislabelx "X" align:#center across:3
	label axislabely "Y" align:#center 
	label axislabelz "Z" align:#center 

	button xaxis90 "90" width:25 align:#center across:3 	on xaxis90 pressed do dorotation (negpos*90) [1,0,0]
	button yaxis90 "90" width:25 align:#center 		on yaxis90 pressed do dorotation (negpos*90) [0,1,0]
	button zaxis90 "90" width:25 align:#center 		on zaxis90 pressed do dorotation (negpos*90) [0,0,1]

	button xaxis45 "45" width:25 align:#center across:3 	on xaxis45 pressed do dorotation (negpos*45) [1,0,0]
	button yaxis45 "45" width:25 align:#center 		on yaxis45 pressed do dorotation (negpos*45) [0,1,0]
	button zaxis45 "45" width:25 align:#center 		on zaxis45 pressed do dorotation (negpos*45) [0,0,1]

	button xaxis30 "30" width:25 align:#center across:3 	on xaxis30 pressed do dorotation (negpos*30) [1,0,0]
	button yaxis30 "30" width:25 align:#center 		on yaxis30 pressed do dorotation (negpos*30) [0,1,0]
	button zaxis30 "30" width:25 align:#center 		on zaxis30 pressed do dorotation (negpos*30) [0,0,1]

	button xaxis10 "10" width:25 align:#center across:3 	on xaxis10 pressed do dorotation (negpos*10) [1,0,0]
	button yaxis10 "10" width:25 align:#center 		on yaxis10 pressed do dorotation (negpos*10) [0,1,0]
	button zaxis10 "10" width:25 align:#center 		on zaxis10 pressed do dorotation (negpos*10) [0,0,1]

	button xaxis5 "05" width:25 align:#center across:3 	on xaxis5 pressed do dorotation (negpos*5) [1,0,0]
	button yaxis5 "05" width:25 align:#center 		on yaxis5 pressed do dorotation (negpos*5) [0,1,0]
	button zaxis5 "05" width:25 align:#center 		on zaxis5 pressed do dorotation (negpos*5) [0,0,1]

	button xaxis1 "01" width:25 align:#center across:3 	on xaxis1 pressed do dorotation (negpos*1) [1,0,0]
	button yaxis1 "01" width:25 align:#center 		on yaxis1 pressed do dorotation (negpos*1) [0,1,0]
	button zaxis1 "01" width:25 align:#center 		on zaxis1 pressed do dorotation (negpos*1) [0,0,1]

	button xaxisr "R" width:25 toolTip:"Random" align:#center across:3 	on xaxisr pressed do dorotation (negpos*(random 0 360)) [1,0,0]
	button yaxisr "R" width:25 toolTip:"Random" align:#center 		on yaxisr pressed do dorotation (negpos*(random 0 360)) [0,1,0]
	button zaxisr "R" width:25 toolTip:"Random" align:#center 		on zaxisr pressed do dorotation (negpos*(random 0 360)) [0,0,1]

	radiobuttons negpositive labels:#("Positive", "Negative")
	on negpositive changed state do 
		(
		if negpositive.state == 1 then negpos = 1
		else negpos = -1
		)

	button axischoicepreset1 "Local" width:80 align:#center toolTip:"Local"
	on axischoicepreset1 pressed do 
		(
		setRefCoordSys #local
		setCoordCenter #local
		)

	button axischoicepreset2 "World" width:80 align:#center toolTip:"World"
	on axischoicepreset2 pressed do 
		(
		setRefCoordSys #world
		setCoordCenter #system
		)

	button axischoicepreset3 "Local Center" width:80 align:#center toolTip:"Local Center"
	on axischoicepreset3 pressed do 
		(
		setRefCoordSys #local
		setCoordCenter #selection
		)
	)

rollout randomscale "RandomScale"
	( 
	button xrandom "RX" width:25 across:3 align:#center toolTip:"Random X Scale"
	on xrandom pressed do scalemyobjectrandomly 1 lowvalue highvalue

	button yrandom "RY" width:25 align:#center toolTip:"Random Y Scale"
	on yrandom pressed do scalemyobjectrandomly 2 lowvalue highvalue

	button zrandom "RZ" width:25 align:#center toolTip:"Random Z Scale"
	on zrandom pressed do scalemyobjectrandomly 3 lowvalue highvalue

	button xyzrandom "RXYZ" width:80 align:#center toolTip:"Random XYZ Scale" 
	on xyzrandom pressed do scalemyobjectrandomly 4 lowvalue highvalue

	spinner lowvaluespinner "Low %" range:[1,1000,25] fieldWidth:40
	on lowvaluespinner changed val do lowvalue = val

	spinner highvaluespinner "High %" range:[1,1000,200] fieldWidth:40
	on highvaluespinner changed val do highvalue = val
	)

rollout moremore "More...More..."
	(
	button copyobject "C" width:25 across:3 align:#center toolTip:"Copy Object"
	on copyobject pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"SimpleRotation")
		else
			(
			selectionSets["MI"] = $
			clearSelection()
			for i = 1 to selectionSets["MI"].count do
				(
				mo = copy selectionSets["MI"][i]
				selectmore mo
				)
			deleteItem selectionSets "MI"
			)
		)

	button instanceobject "I" width:25 align:#center toolTip:"Instance Object"
	on instanceobject pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"SimpleRotation")
		else
			(
			selectionSets["MI"] = $
			clearSelection()
			for i = 1 to selectionSets["MI"].count do
				(
				mo = instance selectionSets["MI"][i]
				selectmore mo
				)
			deleteItem selectionSets "MI"
			)
		)

	button referenceobject "R" width:25 align:#center toolTip:"Reference Object"
	on referenceobject pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"SimpleRotation")
		else
			(
			selectionSets["MI"] = $
			clearSelection()
			for i = 1 to selectionSets["MI"].count do
				(
				mo = reference selectionSets["MI"][i]
				selectmore mo
				)
			deleteItem selectionSets "MI"
			)
		)
	)

rollout clearrollout "Clear"
	(
	button clearposition "P" width:25 across:3 align:#center toolTip:"Clear Position"
	on clearposition pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"Clear")
		else
			(	
			$.pos.x = 0
			$.pos.y = 0
			$.pos.z = 0
			)
		)

	button clearrotation "R" width:25 align:#center toolTip:"Clear Rotation"
	on clearrotation pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"Clear")
		else
			(
			for i = 1 to selection.count do
				(
				a = selection[i].pos.x
				b = selection[i].pos.y
				c = selection[i].pos.z
				selection[i].rotation.x = 0
				selection[i].rotation.y = 0
				selection[i].rotation.z = 0
				selection[i].pos.x = a
				selection[i].pos.y = b
				selection[i].pos.z = c
				)
			)
		)

	button clearscale "S" width:25 align:#center toolTip:"Clear Scale"
	on clearscale pressed do 
		(
		if $ == undefined then (MessageBox "Please Pick an Object" title:"Clear")
		else
			(	
			$.scale.x = 1
			$.scale.y = 1
			$.scale.z = 1
			)
		)
	)

transformtoolsfloater = newRolloutFloater "TransformTools v1.18" 135 625
addRollout copyposition transformtoolsfloater
addRollout simplerotation transformtoolsfloater
addRollout randomscale transformtoolsfloater rolledUp:true 
addRollout moremore transformtoolsfloater
addRollout clearrollout transformtoolsfloater
)
-------------------------------------------------------------------------------
)

MacroScript ClearMedit category:"Soulburn" tooltip:"ClearMedit" Icon:#("Soulburn",4)
(
-------------------------------------------------------------------------------
-- ClearMedit_v130.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.30
-- Created On: 10/19/99
-- Modified On: 05/05/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Clears all or all unused slots in the materials editor (unused is defined as 
-- any slot that is now showing a material currently in your scene) with a 
-- default material that I specify in this script, and that those of you with 
-- maxscript knowledge may edit to your hearts content. 
--
-- Warning, there are several bugs here that stop it from accuractly reporting 
-- what maps and materials are actually in the scene, due to maxscript 
-- limitations. However, the worst that happens is those materials are removed
-- from the editor, they will never be removed from your scene and can be easily
-- gotten back into the editor using get from scene.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 adds ability to clear all slots as well as all unused
--
-- v 1.20 adds ability to replace the slots with raytraced materials as well as
-- standard. Added version number in titlebar.
--
-- v 1.21 fixed a bug that stopped the mat editor from refreshing properly.
--
-- v 1.30 Added ability to clear a range of editor slots.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

ray_yes = 0
on_which_slot_value = 1
on_which_slot_end_value = 24

-- Functions

fn changethematerial currentindex =
	(
	if ray_yes == 1 then newmaterial = RaytraceMaterial ()
	else newmaterial = Standard()
	newmaterial.name = ""
	newmaterial.diffuse = color 137 130 141
	meditMaterials[currentindex] = newmaterial
	)

fn clearall = 
	(
	for i = 1 to 24 do changethematerial i
	)

fn clear_range =
	(
	if on_which_slot_value > on_which_slot_end_value then
		(
		for i = on_which_slot_end_value to on_which_slot_value do
		changethematerial i
		)
	if on_which_slot_value <= on_which_slot_end_value then
		(
		for i = on_which_slot_value to on_which_slot_end_value do
		changethematerial i
		)
	)

fn clearunused = 
	(
	if sceneMaterials.count == 0 then
		for k = 1 to 24 do changethematerial k
		else
			(
			for i = 1 to 24 do
				(
				for j = 1 to sceneMaterials.count do
					(
					if sceneMaterials[j] == meditMaterials[i] then exit
					else
						( 
						if j == sceneMaterials.count then changethematerial i
						else continue
						)
					)
				)
			)
	)

-- Script

rollout clearmeditrollout "ClearMedit"
	(
	checkbox Use_Raytraced "Use Raytraced" align:#center
	on Use_Raytraced changed state do 
		(
		if Use_Raytraced.checked == true then ray_yes = 1
		else ray_yes = 0
		)

	button all "All" width:80 align:#center toolTip:"All"
	on all pressed do clearall()

	button unused "Unused" width:80 align:#center toolTip:"Unused"
	on unused pressed do clearunused()

	button mat_range "Range" width:80 align:#center toolTip:"Range"
	on mat_range pressed do clear_range()

	spinner on_which_slot "Slot: " range:[1,24,1] type:#integer fieldWidth:50 align:#right
	spinner on_which_slot_end "to: " range:[1,24,24] type:#integer fieldWidth:50 align:#right

	on on_which_slot changed val do on_which_slot_value = val
	on on_which_slot_end changed val do on_which_slot_end_value = val
	)

clearmeditfloater = newRolloutFloater "ClearMedit v1.30" 140 210
addRollout clearmeditrollout clearmeditfloater
)
-------------------------------------------------------------------------------
)

-------------------------------------------------------------------------------
-- A Greeble button for those of you who have the plugin
-------------------------------------------------------------------------------

macroScript Greeble category:"Soulburn" tooltip:"Greeble" Icon:#("Soulburn",5)
	(
	AddMod Greeble
 	)

MacroScript MotionBlurSelect category:"Soulburn" tooltip:"MotionBlurSelect" Icon:#("Soulburn",6)
(
-------------------------------------------------------------------------------
-- MotionBlurSelect_v102.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.02
-- Created On: 10/28/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Allows you to select objects based on the type of motionblur you have
-- applied to them. The object must be visible for it to work.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 cleaned the code a bit.
--
-- v 1.02 Added version number to titlebar.
-------------------------------------------------------------------------------

fn blurselect typeofblur =
	(
	max select all
	If $ == undefined then
		(MessageBox "No Objects are currently visible" title:"MotionBlurSelect")
		else
			(
			selectionSets["MJ"] = $
			clearSelection()
			for i = 1 to selectionSets["MJ"].count do
				(
				If typeofblur == 1 then
					(
					If selectionSets["MJ"][i].motionblur == #none then 
						selectmore selectionSets["MJ"][i]
						else continue
					)
				If typeofblur == 2 then
					(
					If selectionSets["MJ"][i].motionblur == #object then 
						selectmore selectionSets["MJ"][i]
						else continue
					)
				If typeofblur == 3 then
					(
					If selectionSets["MJ"][i].motionblur == #image then 
						selectmore selectionSets["MJ"][i]
						else continue
					)
				)
			deleteItem selectionSets "MJ"
			)
	)
	
		
rollout motionblurselectrollout "MotionBlurSelect"
	(
	button noneblur "None" width:60 align:#center toolTip:"None" across:3
	on noneblur pressed do blurselect 1

	button objectblur "Object" width:60 align:#center toolTip:"Object"
	on objectblur pressed do blurselect 2
	
	button imageblur "Image" width:60 align:#center toolTip:"Image"
	on imageblur pressed do blurselect 3
	)

motionblurselectfloater = newRolloutFloater "MotionBlurSelect v1.02" 255 97
addRollout motionblurselectrollout motionblurselectfloater
-------------------------------------------------------------------------------
)

MacroScript SmokeThis category:"Soulburn" tooltip:"SmokeThis" Icon:#("Soulburn",7)
(
-------------------------------------------------------------------------------
-- SmokeThis_v200.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 2.00
-- Created On: 10/29/99
-- Modified On: 05/01/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Makes a superspray with a material that simulates smoke. This is a quick way 
-- to create some smoke for your scene, go into the material afterwards to 
-- tweak its color, density, etc manually.
--
-- WARNING: This script only works if you have avg_dlx.dlx version 2.03 or 
-- higher installed. Get this file from http://www.soulburn3d.com
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Now if you put the smoke material into the material editor, it's a 
-- cube instead of a sphere, making adjusting the effect easier.
--
-- v 1.20 Now the particle system has Shadow casting and receiving turned off
-- by default.
--
-- v 2.00 Added a whole bunch of functionality, now you can create a superspray,
-- or pcloud system, or just get the material to use on something else.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

on_which_slot_value = 1

smokematerial = Standard()
smokematerial.name = "Smoke"
setMTLMeditObjType smokematerial 3

smokematerial.facemap = on
smokematerial.specularlevel = 0
smokematerial.Glossiness = 0
smokematerial.useSelfIllumColor = off
smokematerial.selfIllumAmount = 100

smokematerial.diffuseMap = Gradient ()
smokematerial.diffuseMap.color1 = color 119 119 154
smokematerial.diffuseMap.color2 = color 155 155 198
smokematerial.diffuseMap.color3 = color 219 255 255
smokematerial.diffuseMap.gradientType = 1
smokematerial.diffuseMap.noiseamount = 1
smokematerial.diffuseMap.noiseType = 1
smokematerial.diffuseMap.noiseSize = 3
smokematerial.diffuseMap.noiseLevels = 3

smokematerial.opacityMap = Particle_Age ()
smokematerial.opacityMap.map1 = Mask ()
smokematerial.opacityMap.map1.map = Gradient ()
smokematerial.opacityMap.map1.map.color1 = color 25 25 25
smokematerial.opacityMap.map1.map.color2 = color 128 128 128
smokematerial.opacityMap.map1.map.color3 = color 199 199 199
smokematerial.opacityMap.map1.map.gradientType = 1
smokematerial.opacityMap.map1.map.noiseamount = 1
smokematerial.opacityMap.map1.map.noiseType = 1
smokematerial.opacityMap.map1.map.noiseSize = 3
smokematerial.opacityMap.map1.map.noiseLevels = 3
smokematerial.opacityMap.map1.map.noiseThresholdLow = 0.4
smokematerial.opacityMap.map1.map.output.Output_Amount = 0.10
smokematerial.opacityMap.map1.Mask = Gradient ()
smokematerial.opacityMap.map1.mask.gradientType = 1

smokematerial.opacityMap.map2 = Mask ()
smokematerial.opacityMap.map2.map = Gradient ()
smokematerial.opacityMap.map2.map.color1 = color 25 25 25
smokematerial.opacityMap.map2.map.color2 = color 128 128 128
smokematerial.opacityMap.map2.map.color3 = color 199 199 199
smokematerial.opacityMap.map2.map.gradientType = 1
smokematerial.opacityMap.map2.map.noiseamount = 1
smokematerial.opacityMap.map2.map.noiseType = 1
smokematerial.opacityMap.map2.map.noiseSize = 3
smokematerial.opacityMap.map2.map.noiseLevels = 3
smokematerial.opacityMap.map2.map.noiseThresholdLow = 0.4
smokematerial.opacityMap.map2.map.output.Output_Amount = 0.05
smokematerial.opacityMap.map2.Mask = Gradient ()
smokematerial.opacityMap.map2.mask.gradientType = 1

smokematerial.opacityMap.map3 = Mask ()
smokematerial.opacityMap.map3.map = Gradient ()
smokematerial.opacityMap.map3.map.color1 = color 25 25 25
smokematerial.opacityMap.map3.map.color2 = color 128 128 128
smokematerial.opacityMap.map3.map.color3 = color 199 199 199
smokematerial.opacityMap.map3.map.gradientType = 1
smokematerial.opacityMap.map3.map.noiseamount = 1
smokematerial.opacityMap.map3.map.noiseType = 1
smokematerial.opacityMap.map3.map.noiseSize = 3
smokematerial.opacityMap.map3.map.noiseLevels = 3
smokematerial.opacityMap.map3.map.noiseThresholdLow = 0.4
smokematerial.opacityMap.map3.map.output.Output_Amount = 0.0
smokematerial.opacityMap.map3.Mask = Gradient ()
smokematerial.opacityMap.map3.mask.gradientType = 1

smokematerial.opacityMap.age2 = 75

-- Functions

fn do_superspray =
	(
	SuperSpray speed:3 Speed_Variation:20 Off_Axis:0 Axis_Spread:10 Off_Plane:0 Plane_Spread:5 Birth_Rate:1 Total_Number:100 quantityMethod:0 viewPercent:100 Emitter_Start:0f Emitter_Stop:100f Display_Until:100f life:100f Life_Variation:0f subsampleEmitterTranslation:on subsampleCreationTime:on subsampleEmitterRotation:off size:36 Size_Variation:30 Growth_Time:10f Fade_Time:0f seed:2283 standardParticle:3 Metaparticle_Tension:1 Metaparticle_Tension_Variation:0 metaballAutoCoarsness:on metaballRenderCoarsness:0.5 viewType:1 mappingType:0 Mapping_Time_Base:30f Mapping_Distance_Base:100 Spin_Time:330f Spin_Time_Variation:40 Spin_Phase:0 Spin_Phase_Variation:0 spinAxisType:2 X_Spin_Vector:0 Y_Spin_Vector:2 Z_Spin_Vector:0 Spin_Axis_Variation:0 motionInfluence:100 motionMultiplier:1 motionVariation:0 Bubble_Amplitude:0 Bubble_Amplitude_Variation:0 Bubble_Period:100000f Bubble_Period_Variation:0 Bubble_Phase:0 Bubble_Phase_Variation:0 iconsize:45 iconHidden:off metaballViewCoarsness:1 Spawn_Affects:100 Spawn_Multiplier_Variation:0 Die__X_frames_after_collision:0f Interparticle_Collisions_On:0 Interparticle_Collision_Steps:2 Interparticle_Collision_Bounce:100 Interparticle_Collision_Bounce_Variation:0 pos:[0,0,0] isSelected:on
	$.material = smokematerial
	$.castShadows = off
	$.receiveshadows = off
	)

fn do_pcloud =
	(
	PCloud speed:3 Speed_Variation:20 Birth_Rate:4 Total_Number:100 quantityMethod:0 viewPercent:100 Emitter_Start:0f Emitter_Stop:100f Display_Until:100f life:100f Life_Variation:0f size:36 Size_Variation:30 Growth_Time:10f Fade_Time:0f seed:666 standardParticle:3 Metaparticle_Tension:1 Metaparticle_Tension_Variation:0 metaballAutoCoarsness:on metaballRenderCoarsness:0.5 metaballViewCoarsness:1 viewType:1 mappingType:0 Mapping_Time_Base:30f Mapping_Distance_Base:100 Spin_Time:330f Spin_Time_Variation:40 Spin_Phase:0 Spin_Phase_Variation:0 spinAxisType:0 X_Spin_Vector:1 Y_Spin_Vector:0 Z_Spin_Vector:0 Spin_Axis_Variation:0 motionType: 1 Direction_Vector_X:0 Direction_Vector_Y:1 Direction_Vector_Z:0 motionInfluence:100 motionMultiplier:1 motionVariation:0 Bubble_Amplitude:0 Bubble_Amplitude_Variation:0 Bubble_Period:100000f Bubble_Period_Variation:0 Bubble_Phase:0 Bubble_Phase_Variation:0 Emitter_Rad_Len:20 emitterHidden:off Spawn_Generations:1 Spawn_Multiplier:1 formation:0 Die__X_frames_after_collision:0f Die__X_frames_after_collision_variation:0 Interparticle_Collisions_On:0 Interparticle_Collision_Steps:2 Interparticle_Collision_Bounce:100 Interparticle_Collision_Bounce_Variation:0 Emitter_Width:90 Emitter_Height:90 transform:(matrix3 [1,0,0] [0,0,1] [0,-1,0] [0,0,0]) isSelected:on
	$.material = smokematerial
	$.castShadows = off
	$.receiveshadows = off
	)

fn do_material =
	(
	meditMaterials[on_which_slot_value] = smokematerial
	)

-- The Script

rollout smokethis_rollout "SmokeThis"
	(
	button superspray_button "SuperSpray" width:100 align:#left toolTip:"SuperSpray"
	on superspray_button pressed do do_superspray ()

	button pcloud_button "PCloud" width:100 align:#left toolTip:"PCloud"
	on pcloud_button pressed do do_pcloud ()
	
	button material_button "Material" width:100 align:#left toolTip:"Material" across:2
	on material_button pressed do do_material ()

	spinner on_which_slot "Slot:" range:[1,24,1] type:#integer fieldWidth:40
	on on_which_slot changed val do on_which_slot_value = val
	)

smokethis_floater = newRolloutFloater "SmokeThis v2.00" 230 148
addRollout smokethis_rollout smokethis_floater
)
-------------------------------------------------------------------------------
)

MacroScript RemoveModifier category:"Soulburn" tooltip:"RemoveModifier" Icon:#("Soulburn",8)
(
-------------------------------------------------------------------------------
-- RemoveModifier_v120.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.20
-- Created On: 11/23/99
-- Modified On: 05/11/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Any selected objects will have their modifier stacks checked, and any
-- modifier that you specify in there will be deleted. Current Modifers:
-- Meshsmooth, UVW Mapping, Bend and extrude.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Added ability to remove the Extrude modifier.
--
-- v 1.11 Added version number to titlebar.
--
-- v 1.20 Added ability to remove the Bend modifier.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

killit_array = #()
the_new_array = #()

-- Functions

fn dec_sort the_array =
	(
	the_new_array = #()
	sort the_array
	for w = 1 to the_array.count do
		(
		append the_new_array the_array[the_array.count]
		deleteitem the_array the_array.count
		)
	)

fn kill_the_modifiers selected_object which_modifiers =
	(
	if which_modifiers.count == 0 then continue
	else
		dec_sort which_modifiers
		which_modifiers = the_new_array
		(
		for k = 1 to which_modifiers.count do
			(
			deleteModifier selection[selected_object] selection[selected_object].modifiers[which_modifiers[k]]
			)
		)
	)

fn check_for_the_modifier what_modifier_to_check_for = 
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"RemoveModifier")
	for i = 1 to selection.count do
		(
		killit_array = #()
		if selection[i].modifiers.count == 0 then continue
		else
			(
			for j = 1 to selection[i].modifiers.count do
				(
				if selection[i].modifiers[j].name == what_modifier_to_check_for then 
				append killit_array j 
				else continue
				)
			)
		kill_the_modifiers i killit_array
		)
	)
	
-- The Script

rollout removemodifierrollout "RemoveModifier"
	(
	button but_1 "UVWMapping" width:100 align:#center toolTip:"UVWMapping"
	on but_1 pressed do check_for_the_modifier "UVW Mapping"

	button but_2 "Meshsmooth" width:100 align:#center toolTip:"Meshsmooth"
	on but_2 pressed do check_for_the_modifier "MeshSmooth"

	button but_3 "Extrude" width:100 align:#center toolTip:"Extrude"
	on but_3 pressed do check_for_the_modifier "Extrude"

	button but_4 "Bend" width:100 align:#center toolTip:"Bend"
	on but_4 pressed do check_for_the_modifier "Bend"
	)

removemodifierfloater = newRolloutFloater "RemoveModifier v1.20" 150 173
addRollout removemodifierrollout removemodifierfloater
)
-------------------------------------------------------------------------------
)

MacroScript MeshsmoothControl category:"Soulburn" tooltip:"MeshsmoothControl" Icon:#("Soulburn",9)
(
-------------------------------------------------------------------------------
-- MeshsmoothControl_v121.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.21
-- Created On: 11/23/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Will change various meshsmooth values globally for all selected objects. Any 
-- selected objects will have their modifier stacks checked, and any instance
-- of the meshsmooth modifier will have it's values changed to reflect the
-- global settings you've choosen in the script, even if the modifiers are not
-- instances of the same modifier. You can also copy the display settings to 
-- render settings, and vice versa.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Added more meshsmooth parameters that the script can now affect. Also
-- added the ability to update just part of the meshsmooth information as well
-- as everything.
--
-- v 1.20 Added the ability to copy the display values of each object to the
-- render values fields, and vice versa.
--
-- v 1.21 Added version number to titlebar.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

displayiterationsvalue = 1
displaysmoothnessvalue = 1
render_iterations_enable_value = 0
renderiterationsvalue = 1
render_smoothness_enable_value = 0
rendersmoothnessvalue = 1
meshsmooth_type_value = 0
what_to_change = 4

-- Functions

fn changethestuff theobject themodifier what_to_change2 = 
	(
	if what_to_change2 == 1 then
		(
		selection[theobject].modifiers[themodifier].Quad_Output = meshsmooth_type_value
		)
	if what_to_change2 == 2 then	
		(
		selection[theobject].modifiers[themodifier].iterations = displayiterationsvalue
		selection[theobject].modifiers[themodifier].Smoothness_Filter = displaysmoothnessvalue
		)
	if what_to_change2 == 3 then
		(
		selection[theobject].modifiers[themodifier].Use_Render_Iterations = render_iterations_enable_value
		selection[theobject].modifiers[themodifier].Render_Iterations = renderiterationsvalue
		selection[theobject].modifiers[themodifier].Use_Render_Smoothness = render_smoothness_enable_value
		selection[theobject].modifiers[themodifier].Render_Smoothness = rendersmoothnessvalue
		)
	if what_to_change2 == 4 then
		(
		selection[theobject].modifiers[themodifier].Quad_Output = meshsmooth_type_value
		selection[theobject].modifiers[themodifier].iterations = displayiterationsvalue
		selection[theobject].modifiers[themodifier].Smoothness_Filter = displaysmoothnessvalue
		selection[theobject].modifiers[themodifier].Use_Render_Iterations = render_iterations_enable_value
		selection[theobject].modifiers[themodifier].Render_Iterations = renderiterationsvalue
		selection[theobject].modifiers[themodifier].Use_Render_Smoothness = render_smoothness_enable_value
		selection[theobject].modifiers[themodifier].Render_Smoothness = rendersmoothnessvalue
		)
	if what_to_change2 == 5 then
		(
		selection[theobject].modifiers[themodifier].iterations = selection[theobject].modifiers[themodifier].Render_Iterations
		selection[theobject].modifiers[themodifier].Smoothness_Filter = selection[theobject].modifiers[themodifier].Render_Smoothness
		)
	if what_to_change2 == 6 then
		(
		selection[theobject].modifiers[themodifier].Render_Iterations = selection[theobject].modifiers[themodifier].iterations
		selection[theobject].modifiers[themodifier].Render_Smoothness = selection[theobject].modifiers[themodifier].Smoothness_Filter
		)
	)

fn check_for_the_meshsmooth_modifier what_to_change = 
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"RemoveModifier")
	for i = 1 to selection.count do
		(
		if selection[i].modifiers.count == 0 then continue
		else
			(
			for j = 1 to selection[i].modifiers.count do
				(
				if selection[i].modifiers[j].name == "MeshSmooth" then
				changethestuff i j what_to_change
				else continue
				)
			)
		)
	)

-- The Script

rollout meshsmoothcontrolrollout "MeshsmoothControl"
	(
	
	group "Meshsmooth Type:"
	(
	radiobuttons meshsmooth_type labels:#("Classic", "Quad Output", "NURMS")
	)
	on meshsmooth_type changed state do 
		(
		if meshsmooth_type.state == 1 then meshsmooth_type_value = 0
		if meshsmooth_type.state == 2 then meshsmooth_type_value = 1
		if meshsmooth_type.state == 3 then meshsmooth_type_value = 2
		)

	group "Display Values:"
	(
	spinner displayiterations "Iterations: " range:[0,10,1] fieldWidth:50 type:#integer
	spinner displaysmoothness "Smoothness: " range:[0,1,1] fieldWidth:50
	)

	on displayiterations changed val do displayiterationsvalue = val
	on displaysmoothness changed val do displaysmoothnessvalue = val

	group "Render Values:"
	(
	checkbox render_iterations_enable "" across:2
	spinner renderiterations "Iterations: " range:[0,10,1] fieldWidth:50 type:#integer
	checkbox render_smoothness_enable "" across:2
	spinner rendersmoothness "Smoothness: " range:[0,1,1] fieldWidth:50
	)

	on render_iterations_enable changed state do 
		(
		if render_iterations_enable.checked == true then render_iterations_enable_value = 1
		else render_iterations_enable_value = 0
		)
	on renderiterations changed val do renderiterationsvalue = val
	on render_smoothness_enable changed state do 
		(
		if render_smoothness_enable.checked == true then render_smoothness_enable_value = 1
		else render_smoothness_enable_value = 0
		)
	on rendersmoothness changed val do rendersmoothnessvalue = val

	button update1 "Update MeshSmooth Type" width:150 align:#center toolTip:"Update MeshSmooth Type"
	on update1 pressed do check_for_the_meshsmooth_modifier 1

	button update2 "Update Display Values" width:150 align:#center toolTip:"Update Display Values"
	on update2 pressed do check_for_the_meshsmooth_modifier 2

	button update3 "Update Render Values" width:150 align:#center toolTip:"Update Render Values"
	on update3 pressed do check_for_the_meshsmooth_modifier 3

	button update4 "--- Update Everything ---" width:150 align:#center toolTip:"--- Update Everything ---"
	on update4 pressed do check_for_the_meshsmooth_modifier 4
	)

rollout copyvalues "Copy Values"
	(
	button update5 "Render to Display" width:150 align:#center toolTip:"Copy Render Values to Display Values"
	button update6 "Display to Render" width:150 align:#center toolTip:"Copy Display Values to Render Values"
	on update5 pressed do check_for_the_meshsmooth_modifier 5
	on update6 pressed do check_for_the_meshsmooth_modifier 6
	)

meshsmoothcontrolfloater = newRolloutFloater "MeshsmoothControl v1.21" 205 407
addRollout meshsmoothcontrolrollout meshsmoothcontrolfloater
addRollout copyvalues meshsmoothcontrolfloater rolledUp:true 
)
-------------------------------------------------------------------------------
)

MacroScript SpecularObject category:"Soulburn" tooltip:"SpecularObject" Icon:#("Soulburn",10)
(
-------------------------------------------------------------------------------
-- SpecularObject_v121.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.21
-- Created On: 02/24/00
-- Modified On: 03/06/00
-- tested using Max 3.1
-- Requires "Solid Color" and "Side Fade" available at http://www.blur.com/Blurbeta.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Quickly adds a material to your list of available materials that can be 
-- used to make an object a "light emitter" in raytraced reflections. I'll 
-- explain. The specular highlight we see in objects is mainly made up of the 
-- reflection of the light source. So if your light source is supposed to be 
-- coming from a square light, the highlight should show up in your material as 
-- square (currently, it shows up as round since the "light" is coming from a 
-- point source instead of a true "area"). So to simulate an actual light 
-- source highlight reflection, create your subject, make it partly reflective 
-- and turn it's specular highlight off, create your light to illuminate the 
-- diffuse part of your material, create a stand in object the same approx 
-- shape, size and position as your lightsource (light bulb, neon lighting, 
-- window, whatever), apply the Specular Object Material to it, increase the 
-- energy amount depending on how bright you want your light source to show 
-- up in reflections, then turn the specularObject material to a utility 
-- material (available at www.blur.com/blurbeta) and turn the Render 
-- RayLevels between to 1 to 100, which will make the object appear in 
-- reflections but not appear in your render. Voila, more realistic (but 
-- slower) highlights.
--
-- Thanks to Jobbert Van Strien whose experimentation brought on the idea for 
-- this script.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 A quick fix that makes the energy level and the color parameters
-- more compatible.
--
-- v 1.20 Added ability to use a custom opacity map on your specular object
--
-- v 1.21 Fixed a bug that was causing the interface to display the wrong state
-- of current shape. Thanks Larry.
-------------------------------------------------------------------------------

plugin material SpecularObject
name:"SpecularObject"
classID:#(0x839497cd, 0x6ba168b3)
extends:Standard replaceUI:true

(
	parameters main rollout:params
	(
	Energy type:#float default:1 ui:ener
	on Energy set val do delegate.diffuseMap.output.RGB_Level = val

	Selfillumination type:#float default:100 ui:si
	on Selfillumination set val do delegate.selfIllumAmount = val

	HardEdgeAmount type:#float default:0 ui:hardedge
	on HardEdgeAmount set val do delegate.opacityMap.map1.Control_2 = val

	SoftenSize type:#float default:100 ui:size
	on SoftenSize set val do delegate.opacityMap.map1.low = 100-val

	Color type:#color default:white ui:col
	on Color set val do delegate.diffuseMap.map1.color = val

	CustomOpacityMap type:#texturemap ui:CustomOpacityMap subanim:true
	on CustomOpacityMap set map do delegate.opacityMap.map2 = map
	)

	rollout params "Parameters"
	(
	group "Global"
		(
		colorpicker col "Color: " align:#left across:2
		spinner ener "Energy: " fieldwidth:45 range:[0,50,1] align:#right
		spinner si "Self Illumination.: " fieldwidth:45 range:[0,100,0] align:#right
		)

	group "Shape"
		(
		checkbox softene "Use?" align:#left across:2
		radiobuttons Opacitytype labels:#("Soft Edge", "Custom")
		)

	group "Soft Edge"
		(
		spinner hardedge "Hardness: " fieldwidth:45 range:[0,10,0] align:#right
		spinner size "Size: " fieldwidth:45 range:[0,100,100] align:#right
		)

	group "Custom"
		(
		mapbutton CustomOpacityMap width:150 align:#right
		)

	on params open do 
		(
		softene.state = delegate.opacityMapEnable
		if delegate.opacityMap.mixAmount == 0 then Opacitytype.state = 1
		else Opacitytype.state = 2
		)
	on softene changed state do delegate.opacityMapEnable = state

	on Opacitytype changed state do 
		(
		if Opacitytype.state == 1 then delegate.opacityMap.mixAmount = 0
		else delegate.opacityMap.mixAmount = 100
		)

	label line1 "SpecularObject_v121.ms"
	label line2 "By Neil Blevins (neil@soulburn3d.com)"
	label line3 "v 1.21"
	label line4 "Created On: 02/24/00"
	label line5 "Modified On: 03/06/00"
	label line6 "tested using Max 3.1"
	)

on create do
	(
	delegate.ambient = white
	delegate.diffuse = white
	delegate.specularLevel = 0
	delegate.Glossiness = 0
	delegate.diffuseMap = Output ()
	delegate.diffuseMap.map1 = SolidColor ()
	delegate.opacityMap = Mix ()
	delegate.opacityMap.map1 = Side_Fade ()
	delegate.opacityMap.map1.Control_1 = 0
	delegate.opacityMap.map1.Control_2 = 0
	delegate.opacityMap.map1.low = 10
	delegate.opacityMapEnable = off
	) 
)
-------------------------------------------------------------------------------
)

MacroScript ParticleBuddy category:"Soulburn" tooltip:"ParticleBuddy" Icon:#("Soulburn",11)
(
-------------------------------------------------------------------------------
-- ParticleBuddy_v112.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.12
-- Created On: 03/01/00
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Will change various particle system related values globally for all 
-- selected systems, even between dissimilar particle systems.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Added some more accessible parameters and made the interface more
-- visually appealing.
--
-- v 1.11 The script now properly greys out unused parameters.
--
-- v 1.11 Added version number to titlebar.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

do_displaycount_value = 0
do_iconsize_value = 0
do_birthrate_value = 0
do_emitstart_value = 0
do_emitstop_value = 0
do_displayuntil_value = 0
do_life_value = 0
do_size_value = 0
do_growfor_value = 0
do_fadefor_value = 0
do_newseed_value = 0

displaycount_value = 10
iconsize_value = 50
birthrate_value = 10
emitstart_value = 0
emitstop_value = 100
life_value = 100
size_value = 1
growfor_value = 10
fadefor_value = 10
displayuntil_value = 100

-- Functions

fn dotheupdate theobject = 
	(
	if do_displaycount_value == 1 then 
		(
		selection[theobject].viewPercent = displaycount_value
		)
	if do_iconsize_value == 1 then 
		(
		selection[theobject].iconsize = iconsize_value
		)
	if do_birthrate_value == 1 then 
		(
		selection[theobject].Birth_Rate = birthrate_value
		)
	if do_emitstart_value == 1 then 
		(
		if emitstart_value <= emitstop_value then
			selection[theobject].Emitter_Start = emitstart_value
			else (MessageBox "Your stop value is less then your start value, please reenter new values" title:"ParticleBuddy")
		)
	if do_emitstop_value == 1 then 
		(
		if emitstart_value <= emitstop_value then
			selection[theobject].Emitter_Stop = emitstop_value
			else (MessageBox "Your stop value is less then your start value, please reenter new values" title:"ParticleBuddy")
		)
	if do_displayuntil_value == 1 then 
		(
		selection[theobject].Display_Until = displayuntil_value
		)
	if do_life_value == 1 then 
		(
		selection[theobject].life = life_value
		)
	if do_size_value == 1 then 
		(
		selection[theobject].size = size_value
		)
	if do_growfor_value == 1 then 
		(
		selection[theobject].Growth_Time = growfor_value
		)
	if do_fadefor_value == 1 then 
		(
		selection[theobject].Fade_Time = fadefor_value
		)
	if do_newseed_value == 1 then 
		(
		selection[theobject].seed = random 0 10000
		)
	else continue
	)

fn isitaparticlesystem = 
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"ParticleBuddy")
	for i = 1 to selection.count do
		(
		if classof selection[i].baseobject == SuperSpray or classof selection[i].baseobject == PArray or classof selection[i].baseobject == PCloud or classof selection[i].baseobject == Blizzard then
			(
			dotheupdate i
			)
		else continue
		)
	)

-- The Script

rollout particlebuddyrollout "ParticleBuddy"
	(
	group "Display"
	(
	checkbox do_displaycount "" across:2
	spinner displaycount_spinner "Display Count %: " range:[0,100,10] fieldWidth:50 enabled:false
	checkbox do_iconsize "" across:2
	spinner iconsize_spinner "Icon Size: " range:[0,10000,50] fieldWidth:50 enabled:false
	)
	
	group "Particle Quantity"
	(
	checkbox do_birthrate "" across:2
	spinner birthrate_spinner "Birth Rate: " range:[0,10000,10] fieldWidth:50 enabled:false
	)

	group "Particle Timing"
	(
	checkbox do_emitstart "" across:2
	spinner emitstart_spinner "Emit Start: " range:[-99999,99999,0] fieldWidth:50 enabled:false
	checkbox do_emitstop "" across:2
	spinner emitstop_spinner "Emit Stop: " range:[-99999,99999,100] fieldWidth:50 enabled:false
	checkbox do_displayuntil "" across:2
	spinner displayuntil_spinner "Display Until: " range:[-99999,99999,100] fieldWidth:50 enabled:false
	checkbox do_life "" across:2
	spinner life_spinner "Life: " range:[0,99999,100] fieldWidth:50 enabled:false
	)

	group "Particle Size"
	(
	checkbox do_size "" across:2
	spinner size_spinner "Size: " range:[0,99999,1] fieldWidth:50 enabled:false
	checkbox do_growfor "" across:2
	spinner growfor_spinner "Grow For: " range:[0,99999,10] fieldWidth:50 enabled:false
	checkbox do_fadefor "" across:2
	spinner fadefor_spinner "Fade For: " range:[0,99999,10] fieldWidth:50 enabled:false
	)

	group "Uniqueness"
	(
	checkbox do_newseed "" across:2
	label newseed "New Seed" align:#left offset: [-29,0]
	)

	on do_displaycount changed state do 
		(
		displaycount_spinner.enabled = state
		if do_displaycount.checked == true then do_displaycount_value = 1
		else do_displaycount_value = 0
		)
	on displaycount_spinner changed val do displaycount_value = val
	on do_iconsize changed state do 
		(
		iconsize_spinner.enabled = state
		if do_iconsize.checked == true then do_iconsize_value = 1
		else do_iconsize_value = 0
		)
	on iconsize_spinner changed val do iconsize_value = val
	on do_birthrate changed state do 
		(
		birthrate_spinner.enabled = state
		if do_birthrate.checked == true then do_birthrate_value = 1
		else do_birthrate_value = 0
		)
	on birthrate_spinner changed val do birthrate_value = val
	on do_emitstart changed state do 
		(
		emitstart_spinner.enabled = state
		if do_emitstart.checked == true then do_emitstart_value = 1
		else do_emitstart_value = 0
		)
	on emitstart_spinner changed val do emitstart_value = val
	on do_emitstop changed state do 
		(
		emitstop_spinner.enabled = state
		if do_emitstop.checked == true then do_emitstop_value = 1
		else do_emitstop_value = 0
		)
	on emitstop_spinner changed val do emitstop_value = val
	on do_displayuntil changed state do 
		(
		displayuntil_spinner.enabled = state
		if do_displayuntil.checked == true then do_displayuntil_value = 1
		else do_displayuntil_value = 0
		)
	on displayuntil_spinner changed val do displayuntil_value = val
	on do_life changed state do 
		(
		life_spinner.enabled = state
		if do_life.checked == true then do_life_value = 1
		else do_life_value = 0
		)
	on life_spinner changed val do life_value = val
	on do_size changed state do 
		(
		size_spinner.enabled = state
		if do_size.checked == true then do_size_value = 1
		else do_size_value = 0
		)
	on size_spinner changed val do size_value = val
	on do_growfor changed state do 
		(
		growfor_spinner.enabled = state
		if do_growfor.checked == true then do_growfor_value = 1
		else do_growfor_value = 0
		)
	on growfor_spinner changed val do growfor_value = val
	on do_fadefor changed state do 
		(
		fadefor_spinner.enabled = state
		if do_fadefor.checked == true then do_fadefor_value = 1
		else do_fadefor_value = 0
		)
	on fadefor_spinner changed val do fadefor_value = val
	on do_newseed changed state do 
		(
		if do_newseed.checked == true then do_newseed_value = 1
		else do_newseed_value = 0
		)

	group "Update Parameters"
		(
		button buttonupdate "Update Parameters" width:150 align:#center toolTip:"Update Parameters"
		)
		on buttonupdate pressed do isitaparticlesystem ()
	)

particlebuddyfloater = newRolloutFloater "ParticleBuddy v1.12" 230 474
addRollout particlebuddyrollout particlebuddyfloater
)
-------------------------------------------------------------------------------
)

MacroScript RandomPhase category:"Soulburn" tooltip:"RandomPhase" Icon:#("Soulburn",12)
(
-------------------------------------------------------------------------------
-- RandomPhase_v101.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.01
-- Created On: 03/02/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Whichever material in the material editor you choose, this script will go in
-- and find all maps within that material that have a phase variable and assign 
-- a random number to it. This is useful if say you have two rocks, both with 
-- the same texture on it that contains several levels of procedural noise. By
-- cloning the material, applying it to the second rock, then using this script,
-- the two rocks will now have similar looking textures, but look different from
-- each other due to the phase difference.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Added version number to titlebar.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Functions

fn changephase onwhat = 
	(
	if onwhat.numsubs != 0 then
		(
		for i = 1 to onwhat.numsubs do
			(
			if onwhat[i] != undefined then
				(
				if onwhat[i].numsubs != 0 then
					(
					for j = 1 to onwhat[i].numsubs do
						(
						if onwhat[i][j] != undefined then
							(
							if (getSubAnimNames onwhat[i])[j] == #phase then
							onwhat[i].phase = random 0 500
							)
						)
					)
				)
			changephase onwhat[i]
			)
		)
	)

-- Script

rollout randomphase "RandomPhase"
	(
	button button01 "01" width:25 align:#center across:6 	on button01 pressed do changephase meditMaterials[1][1]
	button button02 "02" width:25 align:#center 		on button02 pressed do changephase meditMaterials[2][1]
	button button03 "03" width:25 align:#center 		on button03 pressed do changephase meditMaterials[3][1]
	button button04 "04" width:25 align:#center 		on button04 pressed do changephase meditMaterials[4][1]
	button button05 "05" width:25 align:#center 		on button05 pressed do changephase meditMaterials[5][1]
	button button06 "06" width:25 align:#center 		on button06 pressed do changephase meditMaterials[6][1]

	button button07 "07" width:25 align:#center across:6 	on button07 pressed do changephase meditMaterials[7][1]
	button button08 "08" width:25 align:#center 		on button08 pressed do changephase meditMaterials[8][1]
	button button09 "09" width:25 align:#center 		on button09 pressed do changephase meditMaterials[9][1]
	button button10 "10" width:25 align:#center 		on button10 pressed do changephase meditMaterials[10][1]
	button button11 "11" width:25 align:#center 		on button11 pressed do changephase meditMaterials[11][1]
	button button12 "12" width:25 align:#center 		on button12 pressed do changephase meditMaterials[12][1]

	button button13 "13" width:25 align:#center across:6 	on button13 pressed do changephase meditMaterials[13][1]
	button button14 "14" width:25 align:#center 		on button14 pressed do changephase meditMaterials[14][1]
	button button15 "15" width:25 align:#center 		on button15 pressed do changephase meditMaterials[15][1]
	button button16 "16" width:25 align:#center 		on button16 pressed do changephase meditMaterials[16][1]
	button button17 "17" width:25 align:#center 		on button17 pressed do changephase meditMaterials[17][1]
	button button18 "18" width:25 align:#center 		on button18 pressed do changephase meditMaterials[18][1]

	button button19 "19" width:25 align:#center across:6 	on button19 pressed do changephase meditMaterials[19][1]
	button button20 "20" width:25 align:#center 		on button20 pressed do changephase meditMaterials[20][1]
	button button21 "21" width:25 align:#center 		on button21 pressed do changephase meditMaterials[21][1]
	button button22 "22" width:25 align:#center 		on button22 pressed do changephase meditMaterials[22][1]
	button button23 "23" width:25 align:#center 		on button23 pressed do changephase meditMaterials[23][1]
	button button24 "24" width:25 align:#center 		on button24 pressed do changephase meditMaterials[24][1]
	)

rollout info "Instructions"
	(
	label label1 "Each number represents a material" align:#left
	label label2 "in the Material Editor. Click on" align:#left
	label label3 "the material's corresponding number" align:#left
	label label4 "to give that material's procedural" align:#left
	label label5 "maps a random phase." align:#left
	)

randomphase_floater = newRolloutFloater "RandomPhase v1.01" 224 194
addRollout randomphase randomphase_floater
addRollout info randomphase_floater rolledUp:true 
)
-------------------------------------------------------------------------------
)

MacroScript GlobalMotionBlur category:"Soulburn" tooltip:"GlobalMotionBlur" Icon:#("Soulburn",13)
(
-------------------------------------------------------------------------------
-- GlobalMotionBlur_v120.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.20
-- Created On: 03/03/00
-- Modified On: 05/02/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Applies image motionblur to every visible object in the scene except to
-- particle systems.
--
-- Written for David Stinnett.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Added ability to apply motionblur to all objects, even hidden ones,
-- made it an option to exlude particle systems, added ability to choose the
-- type of motionblur applied, and made a handy interface.
--
-- v 1.11 Cleaned up the code a bit.
--
-- v 1.12 Added version to titlebar.
--
-- v 1.20 Fixed it so that you can also include/exclude frozen objects, which
-- was a bug fix that became a feature request. Also changed the functions
-- around a lot, making it prettier and more straight forward.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

blurtype_value = 3
hiddenobjects_value = 0
frozenobjects_value = 0
excludeparticles_value = 1

-- Functions

fn setmotionblur currentiteration = 
	(
	if blurtype_value == 1 then selection[currentiteration].motionblur = #none
	if blurtype_value == 2 then selection[currentiteration].motionblur = #object
	if blurtype_value == 3 then selection[currentiteration].motionblur = #image
	)

fn do_the_deed =
	(
	max select all
	if $ != undefined then selectionSets["Stuff_thats_visible"] = $
	if hiddenobjects_value == 1 then
		(
		max unhide all
		max select invert
		if $ != undefined then selectionSets["Stuff_thats_invisible"] = $
		max select all
		)
	if frozenobjects_value == 1 then
		(
		max unfreeze all
		max select invert
		if $ != undefined then selectionSets["Stuff_thats_frozen"] = $
		)
	max select all
	if selection.count !=0 then
		(
		for i = 1 to selection.count do
			(
			if excludeparticles_value == 0 then setmotionblur i
			else
				(
				if classof selection[i].baseobject != SuperSpray and classof selection[i].baseobject != PArray and classof selection[i].baseobject != PCloud and classof selection[i].baseobject != Blizzard and classof selection[i].baseobject != Spray and classof selection[i].baseobject != ParticleStudio and classof selection[i].baseobject != Sand_Blaster and classof selection[i].baseobject != Snow and classof selection[i].baseobject != Particles then setmotionblur i
				)
			)
		)
	if selectionSets["Stuff_thats_invisible"] != undefined then 
		(
		select selectionSets["Stuff_thats_invisible"]
		max hide selection
		)
	if selectionSets["Stuff_thats_frozen"] != undefined then 
		(
		select selectionSets["Stuff_thats_frozen"]
		max freeze selection
		)
	max select none
	if selectionSets["Stuff_thats_visible"] != undefined then deleteItem selectionSets "Stuff_thats_visible"
	if selectionSets["Stuff_thats_invisible"] != undefined then deleteItem selectionSets "Stuff_thats_invisible"
	if selectionSets["Stuff_thats_frozen"] != undefined then deleteItem selectionSets "Stuff_thats_frozen"
	)

-- The Script

rollout globalMotionBlurrollout "GlobalMotionBlur"
	(

	group "Motion Blur Type:"
	(
	radiobuttons blurtype labels:#("None", "Object", "Image") default:3 align:#left
	)
	on blurtype changed state do 
		(
		if blurtype.state == 1 then blurtype_value = 1
		if blurtype.state == 2 then blurtype_value = 2
		if blurtype.state == 3 then blurtype_value = 3
		)

	group "Exclude / Include:"
	(
	checkbox hiddenobjects "Include Hidden Objects" checked:false
	checkbox frozenobjects "Include Frozen Objects" checked:false
	checkbox excludeparticlesystems "Exclude Particle Systems" checked:true
	)
	on hiddenobjects changed state do 
		(
		if hiddenobjects.checked == true then hiddenobjects_value = 1
		else hiddenobjects_value = 0
		)

	on frozenobjects changed state do 
		(
		if frozenobjects.checked == true then frozenobjects_value = 1
		else frozenobjects_value = 0
		)

	on excludeparticlesystems changed state do 
		(
		if excludeparticlesystems.checked == true then excludeparticles_value = 1
		else excludeparticles_value = 0
		)

	button doit "Do it!" width:100 align:#center toolTip:"Do It!"
	on doit pressed do 
		(
		do_the_deed ()
		)
	)

globalMotionBlurfloater = newRolloutFloater "GlobalMotionBlur v1.20" 210 255
addRollout globalMotionBlurrollout globalMotionBlurfloater
)
-------------------------------------------------------------------------------
)

MacroScript Doscript category:"Soulburn" tooltip:"Do" Icon:#("Soulburn",14)
(
-------------------------------------------------------------------------------
-- Do_v103.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.03
-- Created On: 03/09/00
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Allows you to change properties in an object or in a selection of similar 
-- objects or its modifiers. If you want to change the property of the base 
-- object, put the property name in the top field. If you want to change a 
-- modifier property, put a check in the modifier checkbox, choose the modifier 
-- Stack Position (1 being the lowest modifier in the stack) and choose the modifier 
-- property to change. The value you want this property to be is the next field, 
-- of if you want a random value for each object, check the random checkbox and 
-- set your high and low values. The names of properties are the same names 
-- you'd use in a maxscript, if you're unsure of the name of the property, 
-- select an object that has that property, turn your macrorecorder on, change 
-- that property, and the property name will appear in the macrorecorder window. 
-- For example, change a sphere's radius, you'll see $.radius = ??? so the 
-- propety name to stick in the field would be the word "radius" without 
-- quotation marks.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Now instead of by index, it changes properties by modifier name. 
-- Warning, this will now change any modifier in the stack with that name, not
-- just the modifier at a specific index, but that's probably more desirable
-- anyways. Also ui elements now grey out properly when not in use.
--
-- v 1.02 Fixed a bug in which the script would only change the first modifier
-- of any particular name instead of all of them. Now changes all of them,
-- but you now have to use the name of the modifier as it appears in the stack,
-- and the name is case sensitive.
--
-- v 1.03 Added version number to titlebar. And fixed the busted modifier 
-- preset.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

current_property = "radius"
doamodifier = 0
current_modifier_name = "Bend"
current_modifier_property = "angle"
stored_current_modifier_property = "angle"
current_value = 100
stored_current_value = 100
randompropertyvalue_value = 0
randompropertyvaluelow_value = 1
randompropertyvaluehigh_value = 100

-- Functions

fn doit_property = 
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"Do")
	for i = 1 to selection.count do
		(
		if randompropertyvalue_value == 1 then current_value = random randompropertyvaluelow_value randompropertyvaluehigh_value
		try setProperty selection[i] current_property current_value catch (MessageBox "That property doesn't exist in at least one of your selected objects, please reenter" title:"Do")
		)
	)

fn doit_modifier_property =
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"Do")
	for i = 1 to selection.count do
		(
		if selection[i].modifiers.count != 0 then
			(
			for j = 1 to selection[i].modifiers.count do
				(
				if randompropertyvalue_value == 1 then current_value = random randompropertyvaluelow_value randompropertyvaluehigh_value
				if selection[i].modifiers[j].name == current_modifier_name then setProperty selection[i].modifiers[j] current_modifier_property current_value
				)
			)
		)
	)

-- The Script

rollout dorollout "Do"
	(
	group "Object Property:"
	(
	edittext propertytext "Property:" fieldWidth:120 text:"radius" align:#right
	)

	group "Modifier Property:"
	(
	checkbox doamodifier "Modifier?" align:#left
	edittext modifiername "* Modifier Name:" fieldWidth:120 text:"Bend" align:#right enabled:false
	edittext modifierpropertytext "Modifier Property:" fieldWidth:120 text:"angle" align:#right enabled:false
	)

	on propertytext changed text do current_property = propertytext.text
	on doamodifier changed state do
		(
		if doamodifier.checked == true then 
			(
			doamodifier_value = 1
			modifiername.enabled = true
			modifierpropertytext.enabled = true
			propertytext.enabled = false
			)
		else 
			(
			doamodifier_value = 0
			modifiername.enabled = false
			modifierpropertytext.enabled = false
			propertytext.enabled = true
			current_modifier_property = stored_current_modifier_property
			)
		)
	on modifiername changed text do 
		(
		current_modifier_name = modifiername.text
		)
	on modifierpropertytext changed text do 
		(
		current_modifier_property = modifierpropertytext.text
		stored_current_modifier_property = modifierpropertytext.text
		)

	group "Value:"
	(
	spinner propertyvalue "Value: " range:[-99999,99999,100] fieldWidth:50 align:#right
	)

	on propertyvalue changed val do 
		(
		current_value = val
		stored_current_value = val
		)

	group "Random Value:"
	(
	checkbox randompropertyvalue "Random Value?" align:#left
	spinner randompropertyvaluelow "Low: " range:[-99999,99999,1] fieldWidth:50 align:#right enabled:false
	spinner randompropertyvaluehigh "High: " range:[-99999,99999,100] fieldWidth:50 align:#right enabled:false
	)

	on randompropertyvalue changed state do
		(
		if randompropertyvalue.checked == true then 
			(
			randompropertyvalue_value = 1
			propertyvalue.enabled = false
			randompropertyvaluelow.enabled = true
			randompropertyvaluehigh.enabled = true
			)
		else 
			(
			randompropertyvalue_value = 0
			propertyvalue.enabled = true
			randompropertyvaluelow.enabled = false
			randompropertyvaluehigh.enabled = false
			current_value = stored_current_value
			)
		)
	on randompropertyvaluelow changed val do randompropertyvaluelow_value = val
	on randompropertyvaluehigh changed val do randompropertyvaluehigh_value = val

	button doit "Do it!" width:100 align:#center toolTip:"Do It!" align:#right
	on doit pressed do 
		(
		if doamodifier_value == 1 then doit_modifier_property ()
		else doit_property ()
		)

	label label1 "* Modifier name is how it appears in the"
	label label2 "modifier stack and is case sensitive"
	)

rollout info "Instructions"
	(
	label label1 "Allows you to change properties in an object" align:#left
	label label2 "or in a selection of similar objects or its" align:#left
	label label3 "modifiers. If you want to change the property" align:#left
	label label4 "of the base object, put the property name in" align:#left
	label label5 "the top field. If you want to change a" align:#left
	label label6 "modifier property, put a check in the"  align:#left
	label label7 "modifier checkbox, choose the modifier name" align:#left
	label label8 "you want, and choose the modifier property to" align:#left
	label label9 "change. The value you want this property to" align:#left
	label label10 "be is the next field, of if you want a random" align:#left
	label label11 "value for each object, check the random" align:#left
	label label12 "checkbox and set your high and low values." align:#left
	label label13 "The names of properties are the same names" align:#left
	label label14 "you'd use in a maxscript, if you're unsure of" align:#left
	label label15 "the name of the property, select an object" align:#left
	label label16 "recorder on, change that property, and the" align:#left
	label label17 "property name will appear in the macro-" align:#left
	label label18 "recorder window. For example, change a" align:#left
	label label19 "sphere's radius, you'll see $.radius = ???" align:#left
	label label20 "so the propety name to stick in the field" align:#left
	label label21 "would be the word radius." align:#left
	)

dofloater = newRolloutFloater "Do v1.03" 265 423
addRollout dorollout dofloater
addRollout info dofloater rolledUp:true
)
-------------------------------------------------------------------------------
)

MacroScript NoiseControllerRandomSeed category:"Soulburn" tooltip:"NoiseControllerRandomSeed" Icon:#("Soulburn",15)
(
-------------------------------------------------------------------------------
-- NoiseControllerRandomSeed_v101.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.01
-- Created On: 03/10/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Takes all selected objects and finds any noise controllers in them and gives
-- those controllers a random seed.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Added version to titlebar.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

randomlow_value = 1
randomhigh_value = 1000

-- Functions

fn changeseed onwhat = 
	(
	if onwhat.numsubs != 0 then
		(
		for i = 1 to onwhat.numsubs do
			(
			if onwhat[i] != undefined then
				(
				if classof onwhat[i].controller == Noise_position or classof onwhat[i].controller == noise_float or classof onwhat[i].controller == noise_point3 or classof onwhat[i].controller == noise_rotation or classof onwhat[i].controller == noise_scale then
				onwhat[i].seed = random randomlow_value randomhigh_value
				)
			changeseed onwhat[i]
			)
		)
	)

fn toall =
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"NoiseControllerRandomSeed")
	for objectindex = 1 to selection.count do
		(
		changeseed selection[objectindex]
		)
	)		

-- Script

rollout randomseed_rollout "NoiseControllerRandomSeed"
	(
	button Doit "Do it!" width:150 align:#center toolTip:"Do it!"
	on Doit pressed do toall ()
	)

rollout info "Instructions"
	(
	label label1 "Takes all selected objects and finds" align:#left
	label label2 "any noise controllers in them and" align:#left
	label label3 "gives those controllers a random seed." align:#left
	)

randomseed_floater = newRolloutFloater "NoiseControllerRandomSeed v1.01" 224 116
addRollout randomseed_rollout randomseed_floater
addRollout info randomseed_floater rolledUp:true
)
-------------------------------------------------------------------------------
)

MacroScript RemoveNoiseAnimation category:"Soulburn" tooltip:"RemoveNoiseAnimation" Icon:#("Soulburn",16)
(
-------------------------------------------------------------------------------
-- RemoveNoiseAnimation_v101.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.01
-- Created On: 03/10/99
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Ever get pissed off when you apply a noise modifier to an object, open 
-- trackview and say show animated and you see the noise phase has already been 
-- animated for you even though you have no desire to see it since you don't
-- need it animated anyways? Well, me to. This takes any phase animation in
-- any noise modifier in any selected object and deletes the keys.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Added version to titlebar.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Functions

fn killnoiseanim onwhat = 
	(
	if onwhat.numsubs != 0 then
		(
		for i = 1 to onwhat.numsubs do
			(
			if onwhat[i] != undefined then
				(
				if onwhat[i].numsubs != 0 then
					(
					for j = 1 to onwhat[i].numsubs do
						(
						if onwhat[i][j] != undefined then
							(
							if (getSubAnimNames onwhat[i])[j] == #Noise then
							deletekeys onwhat[i][j][8]
							)
						)
					)
				)
			killnoiseanim onwhat[i]
			)
		)
	)

fn killtoall =
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"RemoveNoiseAnimation")
	for objectindex = 1 to selection.count do
		(
		killnoiseanim selection[objectindex]
		)
	)	

-- The Script

rollout removenoiseanimation_rollout "RemoveNoiseAnimation"
	(
	button Doit "Do it!" width:150 align:#center toolTip:"Do it!"
	on Doit pressed do killtoall ()
	)

rollout info "Instructions"
	(
	label label1 "Ever get pissed off when you apply a noise" align:#left
	label label2 "modifier to an object, open trackview and" align:#left
	label label3 "say show animated and you see the noise" align:#left
	label label4 "phase has already been animated for you" align:#left
	label label5 "even though you have no desire to see it" align:#left
	label label6 "since you don't need it animated anyways?" align:#left
	label label7 "Well, me to. This takes any phase animation" align:#left
	label label8 "in any noise modifier in any selected object" align:#left
	label label9 "and deletes the keys." align:#left
	)

removenoiseanimation_floater = newRolloutFloater "RemoveNoiseAnimation v1.01" 265 116
addRollout removenoiseanimation_rollout removenoiseanimation_floater
addRollout info removenoiseanimation_floater rolledUp:true
)
-------------------------------------------------------------------------------
)

MacroScript BigBrother category:"Soulburn" tooltip:"BigBrother" Icon:#("Soulburn",17)
(
-------------------------------------------------------------------------------
-- BigBrother_v171.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.71
-- Created On: 03/20/00
-- Modified On: 05/08/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Creates a list of various scene properties, to show what parts of the scene 
-- the animator may wish to optimize, like shadow maps that don't need to be
-- as big, or uncollapsed modifier stacks that are too deep, etc.
--
-- I feel a little here like that guy who created the first atom bomb. While 
-- this script is very useful in finding areas of your scene where you may 
-- wish to be more efficient, in the wrong hands, information like this can be 
-- used to "prove" numerically the inefficiency of a particular individual. As 
-- any experienced animator knows, using the information you get from this 
-- script to harm another individual in the end harms the company, and therefor 
-- you harm yourself, and no one wants that, so let this and the name of the 
-- script be a warning to you all, use with caution, and use with the intention 
-- of making a faster rendering and better looking scene. Big brother should 
-- be a helping hand, not an iron fist.
--
-- WARNING: This script only works if you have avg_dlx.dlx version 2.03 or higher 
-- installed. Get this file from http://www.soulburn3d.com
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Fixed lots of bugs...
-- 
-- 1) It now filters out objects with no modifiers from the list. 
-- 2) Fixed it so scenes that have a lot of editable meshes in them will 
-- process like 10 times faster. 
-- 3) It now plays fair with objects that have geometric spacewarps applied. 
-- 4) Fixed a bug that would crash the script if a raytraced light was in the 
-- scene.
-- 5) Fixed a bug that would report a negative map depth. 
-- 6) Modifier Stack List is now ordered by number of modifiers
--
-- v 1.10 Now it gathers information on renderable splines too.
--
-- v 1.20 Will now tell the user the name of the group an object is a part of
-- or none if the object isn't part of a group. Also works recursively, so
-- it will accurately report groups that are in groups.
--
-- v 1.30 Cleaned up the code a bit. Also changed the format of the output a 
-- bit to try and make it more readable, hopefully I'll be able to make it
-- even more readable in later versions of the script.
--
-- v 1.40 I'm now using some code provided by Larry Minton to help format the
-- output into columns. Thanks Larry. Also changed the default so all report
-- types are checked when you start the script.
--
-- v 1.50 Added lower bounds to most of the reports, so you can ignore
-- objects that don't meet the minumum requirement.
--
-- v 1.51 Fixed a bug that was causing the script to crash when the mapdepth
-- report checkbox was unchecked.
--
-- v 1.60 Added max value as well as a min value, to help narrow down exactly 
-- what you want in your report. Added a new report that looks for instances
-- of objects (warning, it can be very slow). Combined the modifier count and 
-- list into one function. Moved the min max checking code out of the display
-- code and to the functions themselves, so performance on big scenes will 
-- speed up a bit.
--
-- v 1.61 Removed code for finding the total face count for renderable splines
-- in the scene (use my Renderable Splines Face Count script instead). Report
-- can still be generated showing individual splines. Changed script so that
-- the instance report does not report an instance of itself in the list 
-- (however, the object's own instance is counted towards the instance total,
-- since you want to say "There's 3 instances of this object in the scene")
--
-- v 1.70 Added ability to ignore hidden and frozen objects.
--
-- v 1.71 Fixed a bug that would slow down reporting tremendously if you
-- have more than 40-50 instances of any particular object in your scene.
-- Changed the interface a bit.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

ignore_hidden_value = 0
ignore_frozen_value = 0
min_instance_report_value = 1

do_facecount_value = 1
do_renderablesplines_value = 1
do_findinstances_value = 1
do_modifierstacklist_value = 1
do_shadowcastinglights_value = 1
do_shadowmapsize_value = 1
do_mapdepth_value = 1

facecount_min_value = 1
renderablesplines_min_value = 1
findinstances_min_value = 1
modifierstacklist_min_value = 1
shadowmapsize_min_value = 256
mapdepth_min_value = 1

facecount_max_value = 9999999
renderablesplines_max_value = 9999999
findinstances_max_value = 100
modifierstacklist_max_value = 10
shadowmapsize_max_value = 10000
mapdepth_max_value = 10

facecount_max_enable_value = 0
renderablesplines_max_enable_value = 0
findinstances_max_enable_value = 0
modifierstacklist_max_enable_value = 0
shadowmapsize_max_enable_value = 0
mapdepth_max_enable_value = 0

capamount = 0
segs = 0
finalsegs = 0
splinesteps = 0
maxdepth = 0
numberofshadowcastinglights = 0
ow = 0

facecount_array = #()
renderablesplines_array = #()
findinstances_array = #()
findinstances_single_array = #()
findinstances_compare_array = #()
findinstances_compare_single_array = #()
modifierstacklist_array = #()
modifierstacklist_single_array = #()
shadowmapsize_array = #()
mapdepth_array = #()
groupmember_array = #()

-- Functions

-- Larry's Code, functions Prettify and format_table

-- a function to make pretty output of floats, point3s, and ints
	fn prettify val = 
	(	local res, tval
		if classof val == float then
		(	tval=val
			tval = if abs val < 1e-4 then 0. else val
			res=tval as string
			if res == "0.0" do res = "0.00000"
			if tval >= 0.0 do res = " "+res
			while res.count < 8 do res += "0"
		)
		else if classof val == point3 then
			res = "[" + prettify val.x + "," + prettify val.y + "," + prettify val.z + "]"
		else if classof val == integer then
		(	res = val as string
			while res.count < 8 do res = " "+res
		)
	    else
			res = val as string
		res
	)

-- a function to take an stringstream defining a table output where columns are 
-- separated by tabs, and expand the tabs to spaces to create consistent table 
-- columns. minSpacing is the minimum spacing between columns
	fn format_table outline minSpacing =
	(
		-- get width of columns
		seek outline 0
		local colwidths=#(0)
		local ncol=1
		local colwidth=0
		while not eof outline do 
		(	local inchar = readchar outline
			if inchar == "\t" then
			(	if colwidth > colwidths[ncol] do colwidths[ncol]=colwidth 
				ncol += 1
				if colwidths[ncol] == undefined do colwidths[ncol]=0
				colwidth = 0
			)
			else if inchar == "\n" then
			(	if colwidth > colwidths[ncol] do colwidths[ncol]=colwidth
				ncol = 1
				colwidth = 0
			)
			else
				colwidth += 1
		)
		if colwidth > colwidths[ncol] do colwidths[ncol]=colwidth
		-- output replacing tabs with spaces needed to line up columns
		local newout = stringstream ""
		for i = 1 to colwidths.count do colwidths[i] += minSpacing
		seek outline 0
		ncol=1
		colwidth=0
		while not eof outline do 
		(	local inchar = readchar outline
			if inchar == "\t" then
			(	for i = (colwidth+1) to colwidths[ncol] do format " " to:newout
				ncol += 1
				colwidth = 0
			)
			else if inchar == "\n" then
			(	format inchar to:newout
				ncol = 1
				colwidth = 0
			)
			else
			(	format inchar to:newout
				colwidth += 1
			)
		)
		newout as string
	)

-- Neil's Functions

fn list_the_array inputarray theoutputarea =
	(
	for z = 1 to inputarray.count do
		(
		if z == inputarray.count then
			(
			format "%" inputarray[z] to:theoutputarea
			)
		else
			(
			format "%, " inputarray[z] to:theoutputarea
			)
		)
	)

fn are_you_part_of_a_group inputnode =
	(
	if isgroupmember inputnode == true then 
		(
		if isGroupHead inputnode.parent then
			(
			append groupmember_array inputnode.parent.name
			)
		if isgroupmember inputnode.parent then 
			(
			are_you_part_of_a_group inputnode.parent
			)
		)
	)

fn getfacecount myinput = 
	(
	groupmember_array = #()
	if classof myinput == Editable_mesh and superclassof myinput.modifiers[1] != SpacewarpModifier then
		(
		if myinput.faces.count >= facecount_min_value then
			(
			if facecount_max_enable_value == 1 then
				(
				if myinput.faces.count <= facecount_max_value then
					(
					are_you_part_of_a_group myinput
					append facecount_array #(myinput.name, myinput.faces.count, groupmember_array)
					)
				)
			else
				(
				are_you_part_of_a_group myinput
				append facecount_array #(myinput.name, myinput.faces.count, groupmember_array)
				)
			)
		)
	else
		(
		if validModifier myinput (Mesh_Select ()) == true then 
			(
			addmodifier myinput (Mesh_Select ())
			if myinput.faces.count >= facecount_min_value then
				(
				if facecount_max_enable_value == 1 then
					(
					if myinput.faces.count <= facecount_max_value then
						(
						are_you_part_of_a_group myinput
						append facecount_array #(myinput.name, myinput.faces.count, groupmember_array)
						)
					)
				else
					(
					are_you_part_of_a_group myinput
					append facecount_array #(myinput.name, myinput.faces.count, groupmember_array)
					)
				)
			for wr = 1 to myinput.modifiers.count do
				(
				if classof myinput.modifiers[wr] == Mesh_Select then 
					(
					deleteModifier myinput wr
					exit
					)
				)
			)
		)
	)

fn getsplinefacecount myspline =
	(
	-- Variable Cleaning

	capamount = 0
	segs = 0
	finalsegs = 0
	splinesteps = 0
	groupmember_array = #()

	-- Function

	tempspline = copy myspline
	convertToSplineShape(tempspline)
	for j = 1 to 99999 do
		(
		try 
			(
			if isclosed tempspline j == true then 
				(
				capamount = capamount + 0
				) 
			else
			capamount = capamount + 20
			)
		catch (exit)
		)
	for k = 1 to 99999 do
		(
		try (segs = segs + numSegments tempspline k)
		catch (exit)
		)

	-- capfaces + (Segments * (Steps+1) * number of faces around)
		
	if classof myspline != Helix then
		(
		splinesteps = tempspline.steps + 1
		)
		else splinesteps = 1
	finalsegs = capamount + ((segs * splinesteps) * 24)
	if finalsegs > renderablesplines_min_value then
		(
		if renderablesplines_max_enable_value == 1 then
			(
			if finalsegs < renderablesplines_max_value then
				(
				are_you_part_of_a_group myspline
				append renderablesplines_array #(myspline.name, finalsegs, groupmember_array)
				)
			)
		else
			(
			are_you_part_of_a_group myspline
			append renderablesplines_array #(myspline.name, finalsegs, groupmember_array)
			)
		)
	delete tempspline
	)

fn getinstances myinput =
	(
	groupmember_array = #()
	if (refs.dependents myinput.baseobject).count != 0 then
		(
		for w = 1 to (refs.dependents myinput.baseobject).count do
			(
			if (refs.dependents myinput.baseobject)[w] != myinput then
				(
				if iskindof (refs.dependents myinput.baseobject)[w] (classof myinput) then
					(
					append findinstances_single_array (refs.dependents myinput.baseobject)[w].name
					append findinstances_compare_single_array (refs.dependents myinput.baseobject)[w]
					)
				)
			)
		)
	if findinstances_single_array.count >= findinstances_min_value then
		(
		if findinstances_max_enable_value == 1 then
			(
			if findinstances_single_array.count <= findinstances_max_value then
				(
				are_you_part_of_a_group myinput
				append findinstances_array #(myinput.name, findinstances_single_array.count, findinstances_single_array, groupmember_array)
				)
			)
		else
			(
			are_you_part_of_a_group myinput
			append findinstances_array #(myinput.name,(findinstances_single_array.count + 1), findinstances_single_array, groupmember_array)
			)
		)
	findinstances_compare_array = findinstances_compare_array + findinstances_compare_single_array
	)

fn compareinstances myinput =
	(
	ow = 0
	if findinstances_compare_array.count != 0 then
		(
		for w = 1 to findinstances_compare_array.count do
			(
			if myinput == findinstances_compare_array[w] then ow = 1
			)
		if ow == 0 then getinstances myinput
		)
	else getinstances myinput
	)

fn getmodifierstacklist myinput =
	(
	groupmember_array = #()
	if myinput.modifiers.count >= modifierstacklist_min_value then
		(
		if modifierstacklist_max_enable_value == 1 then
			(
			if myinput.modifiers.count <= modifierstacklist_max_value then
				(
				if (refs.dependents myinput.baseobject).count != 0 then
					(
					for w = 1 to myinput.modifiers.count do
						(
						append modifierstacklist_single_array (classof myinput.modifiers[w])
						)
					)
				are_you_part_of_a_group myinput
				append modifierstacklist_array #(myinput.name, myinput.modifiers.count, modifierstacklist_single_array, groupmember_array)
				)
			)
		else
			(
			if (refs.dependents myinput.baseobject).count != 0 then
				(
				for w = 1 to myinput.modifiers.count do
					(
					append modifierstacklist_single_array (classof myinput.modifiers[w])
					)
				)
			are_you_part_of_a_group myinput
			append modifierstacklist_array #(myinput.name, myinput.modifiers.count, modifierstacklist_single_array, groupmember_array)
			)
		)
	)

fn getshadowcastinglights myinput =
	(
	if myinput.castShadows == true then numberofshadowcastinglights = numberofshadowcastinglights + 1
	)

fn getshadowmapsize myinput =
	(
	groupmember_array = #()
	if myinput.raytracedShadows != true then
		(
		if myinput.mapsize >= shadowmapsize_min_value then
			(
			if shadowmapsize_max_enable_value == 1 then
				(
				if myinput.mapsize <= shadowmapsize_max_value then
					(
					are_you_part_of_a_group myinput
					try (append shadowmapsize_array #(myinput.name, myinput.mapsize, groupmember_array)) catch ()
					)
				)
			else 
				(
				are_you_part_of_a_group myinput
				try (append shadowmapsize_array #(myinput.name, myinput.mapsize, groupmember_array)) catch ()
				)
			)
		)
	)

fn getmapdepth_single onwhat depth = 
	(
	if onwhat.numsubs != 0 then
		(
		for i = 1 to onwhat.numsubs do
			(
			if depth > maxdepth then maxdepth = depth
			getmapdepth_single onwhat[i] (depth+1)
			)
		)
	maxdepth - 2
	)

fn getmapdepth =
	(
	for k = 1 to sceneMaterials.count do
		(
		depth = 0
		maxdepth = 0
		themaxdepth = (getmapdepth_single sceneMaterials[k] 0)
		if themaxdepth < 0 then themaxdepth = 0
		if themaxdepth >= mapdepth_min_value then
			(
			if mapdepth_max_enable_value == 1 then
				(
				if themaxdepth <= mapdepth_max_value then
					(	
					append mapdepth_array #(sceneMaterials[k].name, themaxdepth)
					)
				)
			else
				(
				append mapdepth_array #(sceneMaterials[k].name, themaxdepth)
				)
			)
		)
	)

fn sortthearrays =
	(
	if facecount_array.count > 1 then qsort facecount_array (fn greater_then_sort x y = (y[2] - x[2]))
	if renderablesplines_array.count > 1 then qsort renderablesplines_array (fn greater_then_sort x y = (y[2] - x[2]))
	if findinstances_array.count > 1 then qsort findinstances_array (fn greater_then_sort x y = (y[2] - x[2]))
	if modifierstacklist_array.count > 1 then qsort modifierstacklist_array (fn greater_then_sort x y = (y[2] - x[2]))
	if shadowmapsize_array.count > 1 then qsort shadowmapsize_array (fn greater_then_sort x y = (y[2] - x[2]))
	if mapdepth_array.count > 1 then qsort mapdepth_array (fn greater_then_sort x y = (y[2] - x[2]))
	)

fn showtheoutput = 
	(
	bigbrotherresults = newScript()
	format "---------------------------------------------------------------------------\n" to:bigbrotherresults
	format "Big Brother Results\n" to:bigbrotherresults
	format "---------------------------------------------------------------------------\n" to:bigbrotherresults
	if do_facecount_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Face Count\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable1=stringStream ""
		for j = 1 to facecount_array.count do
			(		
			if facecount_array[j][3].count == 0 then
				(
				format "\t%\t% Faces\n" (prettify facecount_array[j][1]) (prettify facecount_array[j][2]) to:outTable1
				)
			else
				(
				format "\t%\t% Faces" (prettify facecount_array[j][1]) (prettify facecount_array[j][2]) to:outTable1
				format "      Group: " to:outTable1
				list_the_array facecount_array[j][3] outTable1
				format "\n" to:outTable1
				)
			)
		format "%" (format_table outTable1 2) to:bigbrotherresults
		)
	if do_renderablesplines_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Renderable Splines Face Count\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable2=stringStream ""
		format "* Raw Face count, does not include effect of checking the Optimize or Adaptive Checkbox\n" to:bigbrotherresults
		format "\n" to:bigbrotherresults
		for j = 1 to renderablesplines_array.count do
			(
			if renderablesplines_array[j][3].count == 0 then
				(
				format "\t%\t% Faces\n" (prettify renderablesplines_array[j][1]) (prettify renderablesplines_array[j][2]) to:outTable2
				)
			else
				(
				format "\t%\t% Faces" (prettify renderablesplines_array[j][1]) (prettify renderablesplines_array[j][2]) to:outTable2
				format "      Group: " to:outTable2
				list_the_array renderablesplines_array[j][3] outTable2
				format "\n" to:outTable2
				)
			)
		format "%" (format_table outTable2 2) to:bigbrotherresults
		)
	if do_findinstances_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Find Instances\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable3=stringStream ""
		for j = 1 to findinstances_array.count do
			(
			if findinstances_array[j][4].count == 0 then
				(
				tempstream2=stringStream ""
				list_the_array findinstances_array[j][3] tempstream2
				format "\t%\t%\t%\n" (prettify findinstances_array[j][1]) (prettify findinstances_array[j][2]) (prettify tempstream2) to:outTable3
				)
			else
				(
				tempstream2=stringStream ""
				list_the_array findinstances_array[j][3] tempstream2
				tempstream3=stringStream ""
				list_the_array findinstances_array[j][4] tempstream3
				format "\t%\t%\t%\tGroup: %\n" (prettify findinstances_array[j][1]) (prettify findinstances_array[j][2]) (prettify tempstream2) (prettify tempstream3) to:outTable3
				)
			)
		format "%" (format_table outTable3 2) to:bigbrotherresults
		)
	if do_modifierstacklist_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Modifier Stack List\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable4=stringStream ""
		for j = 1 to modifierstacklist_array.count do
			(
			if modifierstacklist_array[j][4].count == 0 then
				(
				tempstream2=stringStream ""
				list_the_array modifierstacklist_array[j][3] tempstream2
				format "\t%\t%\t%\n" (prettify modifierstacklist_array[j][1]) (prettify modifierstacklist_array[j][2]) (prettify tempstream2) to:outTable4
				)
			else
				(
				tempstream2=stringStream ""
				list_the_array modifierstacklist_array[j][3] tempstream2
				tempstream3=stringStream ""
				list_the_array modifierstacklist_array[j][4] tempstream3
				format "\t%\t%\t%\tGroup: %\n" (prettify modifierstacklist_array[j][1]) (prettify modifierstacklist_array[j][2]) (prettify tempstream2) (prettify tempstream3) to:outTable4
				)
			)
		format "%" (format_table outTable4 2) to:bigbrotherresults
		)
	if do_shadowcastinglights_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Shadow Casting Lights\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		format "Number Of Shadow Casting Lights:%\n" numberofshadowcastinglights to:bigbrotherresults
		)
	if do_shadowmapsize_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Shadow Map Sizes\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable5=stringStream ""
		for j = 1 to shadowmapsize_array.count do
			(
			if shadowmapsize_array[j][3].count == 0 then
				(
				format "\t%\t%\n" (prettify shadowmapsize_array[j][1]) (prettify shadowmapsize_array[j][2]) to:outTable5
				)
			else
				(
				format "% %" (prettify shadowmapsize_array[j][1]) (prettify shadowmapsize_array[j][2]) to:outTable5
				format "      Group: " to:outTable5
				list_the_array shadowmapsize_array[j][3] outTable5
				format "\n" to:outTable5
				)
			)
		format "%" (format_table outTable5 2) to:bigbrotherresults
		)
	if do_mapdepth_value == 1 then
		(
		format "\n" to:bigbrotherresults
		format "Map Depth\n" to:bigbrotherresults
		format "---------------------------------------------------------------------------\n" to:bigbrotherresults
		outTable6=stringStream ""
		for j = 1 to mapdepth_array.count do
			(
			format "\t%\t% Levels\n" (prettify mapdepth_array[j][1]) (prettify mapdepth_array[j][2]) to:outTable6
			)
		format "%" (format_table outTable6 2) to:bigbrotherresults
		)
	)

fn dothesearch =
	(
	-- Clear

	capamount = 0
	segs = 0
	finalsegs = 0
	splinesteps = 0
	maxdepth = 0
	numberofshadowcastinglights = 0

	facecount_array = #()
	renderablesplines_array = #()
	findinstances_array = #()
	findinstances_single_array = #()
	findinstances_compare_array = #()
	findinstances_compare_single_array = #()
	modifierstacklist_array = #()
	modifierstacklist_single_array = #()
	shadowmapsize_array = #()
	mapdepth_array = #()
	groupmember_array = #()

	-- Do The Search

	for i = 1 to selection.count do
		(
		if superclassof selection[i] == GeometryClass and do_facecount_value == 1 then getfacecount selection[i]
		if superclassof selection[i] == shape and selection[i].renderable == true and do_renderablesplines_value == 1 then getsplinefacecount selection[i]
		if do_findinstances_value == 1 then 
			(
			if min_instance_report_value == 1 then compareinstances selection[i]
			else getinstances selection[i]
			)
		if superclassof selection[i] == GeometryClass and do_modifierstacklist_value == 1 then getmodifierstacklist selection[i]
		if superclassof selection[i] == light and do_shadowcastinglights_value == 1 then getshadowcastinglights selection[i]
		if superclassof selection[i] == light and do_shadowmapsize_value == 1 and selection[i].castShadows == true then getshadowmapsize selection[i]
		findinstances_single_array = #()
		modifierstacklist_single_array = #()
		findinstances_compare_single_array = #()
		)
	if do_mapdepth_value == 1 then getmapdepth ()
	sortthearrays ()
	showtheoutput ()
	)

fn get_obj = 
	(
	max select all
	if $ != undefined then selectionSets["Stuff_thats_visible"] = $
	if ignore_hidden_value == 0 then
		(
		max unhide all
		max select invert
		if $ != undefined then selectionSets["Stuff_thats_invisible"] = $
		max select all
		)
	if ignore_frozen_value == 0 then
		(
		max unfreeze all
		max select invert
		if $ != undefined then selectionSets["Stuff_thats_frozen"] = $
		)
	)

fn release_obj = 
	(
	if selectionSets["Stuff_thats_invisible"] != undefined then 
		(
		select selectionSets["Stuff_thats_invisible"]
		max hide selection
		)
	if selectionSets["Stuff_thats_frozen"] != undefined then 
		(
		select selectionSets["Stuff_thats_frozen"]
		max freeze selection
		)
	max select none
	if selectionSets["Stuff_thats_visible"] != undefined then deleteItem selectionSets "Stuff_thats_visible"
	if selectionSets["Stuff_thats_invisible"] != undefined then deleteItem selectionSets "Stuff_thats_invisible"
	if selectionSets["Stuff_thats_frozen"] != undefined then deleteItem selectionSets "Stuff_thats_frozen"
	)

fn check_for_min_max_probs =
	(
	if facecount_max_value < facecount_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	if renderablesplines_max_value < renderablesplines_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	if findinstances_max_value < findinstances_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	if modifierstacklist_max_value < modifierstacklist_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	if shadowmapsize_max_value < shadowmapsize_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	if mapdepth_max_value < mapdepth_min_value then 
		(MessageBox "One of your min values is greater then it's corresponding max value. Please reenter."  title:"BigBrother")
	)

fn get_objects_ready = 
	(
	get_obj ()
	check_for_min_max_probs ()
	max select all
	dothesearch ()
	release_obj ()
	)

-- The Script

rollout bigbrother_rollout "BigBrother"
	(

	group "Report Types"
	(
	checkbox do_facecount "Face Count" checked:true across:4
	spinner facecount_min "Min: " range:[0,9999999,1] fieldWidth:60 type:#integer offset:[70,0]
	spinner facecount_max "Max: " range:[0,9999999,9999999] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox facecount_max_enable "" offset:[81,0]

	checkbox do_renderablesplines "Renderable Splines Face Count" checked:true across:4
	spinner renderablesplines_min "Min: " range:[0,9999999,1] fieldWidth:60 type:#integer offset:[70,0]
	spinner renderablesplines_max "Max: " range:[0,9999999,9999999] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox renderablesplines_max_enable "" offset:[81,0]

	checkbox do_findinstances "Find Instances" checked:true across:4
	spinner findinstances_min "Min: " range:[0,99999,1] fieldWidth:60 type:#integer offset:[70,0]
	spinner findinstances_max "Max: " range:[0,99999,100] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox findinstances_max_enable "" offset:[81,0]

	checkbox do_modifierstacklist "Modifier Stack List" checked:true across:4
	spinner modifierstacklist_min "Min: " range:[0,99999,1] fieldWidth:60 type:#integer offset:[70,0]
	spinner modifierstacklist_max "Max: " range:[0,99999,10] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox modifierstacklist_max_enable "" offset:[81,0]

	checkbox do_shadowcastinglights "Shadow Casting Lights" checked:true align:#left

	checkbox do_shadowmapsize "Shadow Map Size" checked:true across:4
	spinner shadowmapsize_min "Min: " range:[0,99999,256] fieldWidth:60 type:#integer offset:[70,0]
	spinner shadowmapsize_max "Max: " range:[0,99999,10000] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox shadowmapsize_max_enable "" offset:[81,0]

	checkbox do_mapdepth "Map Depth" checked:true across:4
	spinner mapdepth_min "Min: " range:[0,99999,1] fieldWidth:60 type:#integer offset:[70,0]
	spinner mapdepth_max "Max: " range:[0,99999,10] fieldWidth:60 type:#integer enabled:false offset:[75,0]
	checkbox mapdepth_max_enable "" offset:[81,0]
	)

	on do_facecount changed state do 
		(
		if do_facecount.checked == true then do_facecount_value = 1
		else do_facecount_value = 0
		)
	on facecount_min changed val do facecount_min_value = val
	on facecount_max changed val do facecount_max_value = val
	on facecount_max_enable changed state do 
		(
		facecount_max.enabled = state
		if facecount_max_enable.checked == true then facecount_max_enable_value = 1
		else facecount_max_enable_value = 0
		)

	on do_renderablesplines changed state do 
		(
		if do_renderablesplines.checked == true then do_renderablesplines_value = 1
		else do_renderablesplines_value = 0
		)
	on renderablesplines_min changed val do renderablesplines_min_value = val
	on renderablesplines_max changed val do renderablesplines_max_value = val
	on renderablesplines_max_enable changed state do 
		(
		renderablesplines_max.enabled = state
		if renderablesplines_max_enable.checked == true then renderablesplines_max_enable_value = 1
		else renderablesplines_max_enable_value = 0
		)

	on do_findinstances changed state do 
		(
		if do_findinstances.checked == true then do_findinstances_value = 1
		else do_findinstances_value = 0
		)
	on findinstances_min changed val do findinstances_min_value = val
	on findinstances_max changed val do findinstances_max_value = val
	on findinstances_max_enable changed state do 
		(
		findinstances_max.enabled = state
		if findinstances_max_enable.checked == true then findinstances_max_enable_value = 1
		else findinstances_max_enable_value = 0
		)

	on do_modifierstacklist changed state do 
		(
		if do_modifierstacklist.checked == true then do_modifierstacklist_value = 1
		else do_modifierstacklist_value = 0
		)
	on modifierstacklist_min changed val do modifierstacklist_min_value = val
	on modifierstacklist_max changed val do modifierstacklist_max_value = val
	on modifierstacklist_max_enable changed state do 
		(
		modifierstacklist_max.enabled = state
		if modifierstacklist_max_enable.checked == true then modifierstacklist_max_enable_value = 1
		else modifierstacklist_max_enable_value = 0
		)

	on do_shadowcastinglights changed state do 
		(
		if do_shadowcastinglights.checked == true then do_shadowcastinglights_value = 1
		else do_shadowcastinglights_value = 0
		)

	on do_shadowmapsize changed state do 
		(
		if do_shadowmapsize.checked == true then do_shadowmapsize_value = 1
		else do_shadowmapsize_value = 0
		)
	on shadowmapsize_min changed val do shadowmapsize_min_value = val
	on shadowmapsize_max changed val do shadowmapsize_max_value = val
	on shadowmapsize_max_enable changed state do 
		(
		shadowmapsize_max.enabled = state
		if shadowmapsize_max_enable.checked == true then shadowmapsize_max_enable_value = 1
		else shadowmapsize_max_enable_value = 0
		)

	on do_mapdepth changed state do 
		(
		if do_mapdepth.checked == true then do_mapdepth_value = 1
		else do_mapdepth_value = 0
		)
	on mapdepth_min changed val do mapdepth_min_value = val
	on mapdepth_max changed val do mapdepth_max_value = val
	on mapdepth_max_enable changed state do 
		(
		mapdepth_max.enabled = state
		if mapdepth_max_enable.checked == true then mapdepth_max_enable_value = 1
		else mapdepth_max_enable_value = 0
		)

	group "Options"
	(
	checkbox ignore_hidden "Ignore Hidden" across:3
	checkbox ignore_frozen "Ignore Frozen"
	checkbox min_instance_report "Minimize Instance Report" checked:true
	)

	group "Make Report"
	(
	button Doit "Make Report" width:130 align:#center toolTip:"Make Report"
	)

	on Doit pressed do get_objects_ready ()
	on ignore_hidden changed state do 
		(
		if ignore_hidden.checked == true then ignore_hidden_value = 1
		else ignore_hidden_value = 0
		)
	on ignore_frozen changed state do 
		(
		if ignore_frozen.checked == true then ignore_frozen_value = 1
		else ignore_frozen_value = 0
		)
	on min_instance_report changed state do 
		(
		if min_instance_report.checked == true then min_instance_report_value = 1
		else 
			(
			min_instance_report_value = 0
			(MessageBox "Warning: This could make the Find Instances report very slow if you have more then 40-50 instances of any particular object in your scene." title:"BigBrother")
			)
		)
	)

bigbrother_floater = newRolloutFloater "BigBrother v1.71" 465 335
addRollout bigbrother_rollout bigbrother_floater
)
-------------------------------------------------------------------------------
)

MacroScript RenderableSplineFaceCount category:"Soulburn" tooltip:"RenderableSplineFaceCount" Icon:#("Soulburn",18)
(
-------------------------------------------------------------------------------
-- RenderableSplineFaceCount_v101.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.01
-- Created On: 03/25/00
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Takes any renderable splines that are selected and gives you back the number
-- of faces they'll create when rendered. Also included are two utility buttons
-- that makes all selected splines either renderable or non renderable.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Added version in titlebar.
-------------------------------------------------------------------------------
(
-- Variables

capamount = 0
renderable_spline_face_count_all_value = 0
segs = 0
finalsegs = 0
splinesteps = 0

-- Functions

fn splinefacecount myspline =
	(
	-- Variable Cleaning

	capamount = 0
	segs = 0
	finalsegs = 0
	splinesteps = 0

	-- Function

	tempspline = copy myspline
	convertToSplineShape(tempspline)
	for j = 1 to 99999 do
		(
		try 
			(
			if isclosed tempspline j == true then 
				(
				capamount = capamount + 0
				)
			else
			capamount = capamount + 20
			)
		catch (exit)
		)
	for k = 1 to 99999 do
		(
		try (segs = segs + numSegments tempspline k)
		catch (exit)
		)	

	-- capfaces + (Segments * (Steps+1) * number of faces around)
		
	if classof myspline != Helix then
		(
		splinesteps = tempspline.steps + 1
		)
		else splinesteps = 1
	finalsegs = capamount + ((segs * splinesteps) * 24)
	renderable_spline_face_count_all_value = renderable_spline_face_count_all_value + finalsegs
	delete tempspline
	)

fn renderable_spline_face_count_all = 
	(
	renderable_spline_face_count_all_value = 0
	if selection.count != 0 then 
		(
		for i = 1 to selection.count do 
			if superclassof selection[i] == shape and selection[i].renderable == true then splinefacecount selection[i]
		)
	else (MessageBox "Please pick at least one object." title:"RenderableSplineFaceCount")
	s1 = "Number Of Faces Created By Selected Renderable Splines: " 
	s2 = renderable_spline_face_count_all_value as string
	s3 = s1 + s2
	(MessageBox s3 title:"RenderableSplineFaceCount")
	)

fn make_selected_splines_renderable_function = 
	(
	if selection.count != 0 then 
		(
		for i = 1 to selection.count do 
			if superclassof selection[i] == shape then selection[i].renderable = true
		)
	else (MessageBox "Please pick at least one object." title:"RenderableSplineFaceCount")
	)

fn make_selected_splines_nonrenderable_function = 
	(
	if selection.count != 0 then 
		(
		for i = 1 to selection.count do 
			if superclassof selection[i] == shape then selection[i].renderable = false
		)
	else (MessageBox "Please pick at least one object." title:"RenderableSplineFaceCount")
	)

-- The Script

rollout renderable_spline_face_count_rollout "RenderableSplineFaceCount"
	(
	button face_count_for_selected "Face Count For Selected" width:220 align:#center toolTip:"Face Count For Selected"
	on face_count_for_selected pressed do renderable_spline_face_count_all ()

	button make_selected_splines_renderable "Make Selected Splines Renderable" width:220 align:#center toolTip:"Make Selected Splines Renderable"
	on make_selected_splines_renderable pressed do make_selected_splines_renderable_function ()

	button make_selected_splines_nonrenderable "Make Selected Splines Non Renderable" width:220 align:#center toolTip:"Make Selected Splines Non Renderable"
	on make_selected_splines_nonrenderable pressed do make_selected_splines_nonrenderable_function ()
	)

renderable_spline_face_count_floater = newRolloutFloater "RenderableSplineFaceCount v1.01" 280 150
addRollout renderable_spline_face_count_rollout renderable_spline_face_count_floater
)
-------------------------------------------------------------------------------
)

macroScript Select_Patch_Verts category:"Patch Toolbox" toolTip:"Select Patch Verticies" Icon:#("PolyTools",12)
(
MyRCmenu.mi_PVerts.picked()
)

macroScript Select_Patch_Edges category:"Patch Toolbox" toolTip:"Select Patch Edges" Icon:#("PolyTools",11)
(
MyRCmenu.mi_PEdges.picked()
)

macroScript Select_Patch_Patch category:"Patch Toolbox" toolTip:"Select Patch Patches" Icon:#("PolyTools",14)
(
MyRCmenu.mi_PPatch.picked()
)

MacroScript RenderCam category:"Soulburn" tooltip:"RenderCam" Icon:#("Soulburn",19)
(
-------------------------------------------------------------------------------
-- RenderCam_v101.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.01
-- Created On: 04/19/00
-- Modified On: 04/29/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- When running (and on is pressed) will output a sequence of rendered images 
-- of whatever was in your camera view at the current interval time. Useful 
-- for outputing a sequential set of images showing the progress of you 
-- building your scene. Minimize the script (don't close it) to let it run 
-- without cluttering your view.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.01 Added version number to titlebar. Also made it so that the images 
-- created have a 4 digit number such as 0000 instead of 0.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

clockon = 0
intervaltime_min = 20
intervaltime_ticks = 20*60000
camerapicked = 0
i = 0
extra_zero = ""

out_dir = "d:\\shiva\\images\\"
out_filename = "rendercam"
out_filetype = ".jpg"

-- Functions

fn what_to_do = 
	(
	extra_zero = ""
	i = i + 1
	if i <= 999 then extra_zero = "0"
	if i <= 99 then extra_zero = "00"
	if i <= 9 then extra_zero = "000"
	out_name = out_dir + out_filename + extra_zero + i as string + out_filetype
	render camera: mycamera frame: 0 outputfile: out_name vfb: off
	gc()
	)

fn cam_filter o = 
	(
	superClassOf o == camera 
	)

-- The Script

rollout rendercam_rollout "RenderCam"
	(
	timer myclock interval:intervaltime_ticks
	on myclock tick do 
		(
		if clockon == 1 then what_to_do ()
		)

	group "Camera"
	(
	label what_camera "None" align:#center

	pickbutton pickthecamera "Pick The Camera" width:120 align:#center toolTip:"Pick The Camera" filter:cam_filter
	)
	on pickthecamera picked obj do 
		(
		camerapicked = 1
		mycamera = obj
		what_camera.text = obj.name		
		)

	group "Time"
	(
	spinner intervaltime_spinner "Interval Time (min): " range:[1,99999,20] fieldWidth:35 type:#integer align:#center
	)
	on intervaltime_spinner changed val do 
		(
		intervaltime_min = val
		intervaltime_ticks = intervaltime_min * 60000
		myclock.interval = intervaltime_ticks
		)

	group "Files"
	(
	edittext dir_text "Dir:" fieldWidth:120 text:"d:\\shiva\\images\\" align:#right
	edittext filename_text "Name:" fieldWidth:120 text:"rendercam" align:#right
	edittext filetype_text "Type:" fieldWidth:120 text:".jpg" align:#right
	)

	on dir_text changed text do 
		(
		i = 0
		out_dir = dir_text.text
		)
	on filename_text changed text do 
		(
		i = 0
		out_filename = filename_text.text
		)
	on filetype_text changed text do 
		(
		i = 0
		out_filetype = filetype_text.text
		)

	group "Status"
	(
	label on_or_off "off" align:#center

	button startthecam "On" width:70 align:#center toolTip:"On" across:2
	button stopthecam "Off" width:70 align:#center toolTip:"Off"
	)

	on startthecam pressed do 
		(
		if camerapicked == 1 then
			(
			clockon = 1
			on_or_off.text = "on"
			)
		else (MessageBox "Please select a camera first" title:"RenderCam")
		)
	
	on stopthecam pressed do 
		(
		clockon = 0
		on_or_off.text = "off"
		)
	)

rendercam_floater = newRolloutFloater "RenderCam v1.01" 210 345
addRollout rendercam_rollout rendercam_floater
)
-------------------------------------------------------------------------------
)

MacroScript MaterialRenamer category:"Soulburn" tooltip:"MaterialRenamer" Icon:#("Soulburn",20)
(
-------------------------------------------------------------------------------
-- MaterialRenamer_v120.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.20
-- Created On: 04/28/00
-- Modified On: 05/01/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Allows you to rename the materials in your scene in various ways (prefix, 
-- total rename, append number, etc) For Tom, and everyone else who finds it 
-- useful.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Revision History:
--
-- v 1.10 Added a lot of new functionality, including a new interface, more
-- renaming options, specifying what materials to perform the operations on, 
-- etc.
--
-- v 1.20 Added a material slot range to the things you can change.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

rename_type = 1
number_start = 1
number_step = 1
on_what_value = 1
on_which_slot_value = 1
on_which_slot_end_value = 24
inc = 0
operation_text_text = "NewMaterial"
extra_zero == ""

-- Functions

fn do_the_rename the_mat =
	(
	if rename_type == 1 then 
		(
		name_prefix = ""
		main_name = operation_text_text
		name_postfix = ""
		the_mat.name = name_prefix + main_name + name_postfix
		inc = inc + (1 * number_step)
		)
	if rename_type == 2 then 
		(
		name_prefix = operation_text_text
		main_name = the_mat.name
		name_postfix = ""
		the_mat.name = name_prefix + main_name + name_postfix
		inc = inc + (1 * number_step)
		)
	if rename_type == 3 then 
		(
		name_prefix = ""
		main_name = the_mat.name
		name_postfix = operation_text_text
		the_mat.name = name_prefix + main_name + name_postfix
		inc = inc + (1 * number_step)
		)
	if rename_type == 4 then 
		(		
		name_prefix = ""
		main_name = the_mat.name
		name_postfix = ""
		extra_zero = ""
		if (number_start + inc) <= 9 then extra_zero = "0"
		the_mat.name = name_prefix + main_name + name_postfix + extra_zero + ((number_start + inc) as string)
		inc = inc + (1 * number_step)
		)
	)

fn choose_the_material =
	(
	inc = 0
	if on_what_value == 1 then
		(
		for i = 1 to sceneMaterials.count do do_the_rename sceneMaterials[i]
		)
	if on_what_value == 2 then
		(
		for i = 1 to 24 do do_the_rename meditMaterials[i]
		)
	if on_what_value == 3 then
		(
		do_the_rename meditMaterials[on_which_slot_value]
		)
	if on_what_value == 4 then
		(
		if on_which_slot_value > on_which_slot_end_value then
			(
			for i = on_which_slot_end_value to on_which_slot_value do
			do_the_rename meditMaterials[i]
			)
		if on_which_slot_value <= on_which_slot_end_value then
			(
			for i = on_which_slot_value to on_which_slot_end_value do
			do_the_rename meditMaterials[i]
			)
		)
	)

-- Script

rollout materialrenamer_rollout "Material Renamer"
	(

	group "Rename:"
	(
	button full_rename "Full Rename:" width:150 align:#center toolTip:"Full Rename"
	button name_prefix "Add Prefix:" width:150 align:#center toolTip:"Add Prefix"
	button name_postfix "Append Postfix:" width:150 align:#center toolTip:"Append Postfix"
	edittext operation_text "Text To Use:" fieldWidth:100 text:"NewMaterial" align:#center
	)

	on full_rename pressed do 
		(
		rename_type = 1
		choose_the_material ()
		)
	on name_prefix pressed do 
		(
		rename_type = 2
		choose_the_material ()
		)
	on name_postfix pressed do 
		(
		rename_type = 3
		choose_the_material ()
		)
	on operation_text changed text do 
		(
		operation_text_text = operation_text.text
		)

	group "Append Number:"
	(
	button do_append_number "Append Number" width:150 align:#center toolTip:"Append Number"
	spinner append_number_start "Start: " range:[0,999999,1] type:#integer fieldWidth:50 align:#center
	spinner append_number_step "Step: " range:[0,999999,1] type:#integer fieldWidth:50 align:#center
	)

	on do_append_number pressed do 
		(
		rename_type = 4
		choose_the_material ()
		)
	on append_number_start changed val do number_start = val
	on append_number_step changed val do number_step = val

	group "On What?"
	(
	radiobuttons on_what labels:#("All Scene Materials", "All Material Editor Slots", "Material Editor Slot", "Material Editor Slot Range")
	spinner on_which_slot "Slot: " range:[1,24,1] type:#integer fieldWidth:50 align:#center enabled:false across:2
	spinner on_which_slot_end "to: " range:[1,24,24] type:#integer fieldWidth:50 align:#center enabled:false
	)

	on on_what changed state do 
		(
		if on_what.state == 1 then 
			(
			on_what_value = 1
			on_which_slot.enabled = false
			on_which_slot_end.enabled = false
			)
		if on_what.state == 2 then 
			(
			on_what_value = 2
			on_which_slot.enabled = false
			on_which_slot_end.enabled = false
			)
		if on_what.state == 3 then 
			(
			on_what_value = 3
			on_which_slot.enabled = true
			on_which_slot_end.enabled = false
			)
		if on_what.state == 4 then 
			(
			on_what_value = 4
			on_which_slot.enabled = true
			on_which_slot_end.enabled = true
			)
		)
	on on_which_slot changed val do on_which_slot_value = val
	on on_which_slot_end changed val do on_which_slot_end_value = val
	)

materialrenamer_floater = newRolloutFloater "Material Renamer v1.20" 230 400
addRollout materialrenamer_rollout materialrenamer_floater
)
-------------------------------------------------------------------------------
)

MacroScript HollowCube category:"Soulburn" tooltip:"HollowCube" Icon:#("Soulburn",21)
(
-------------------------------------------------------------------------------
-- HollowCube_v100.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.00
-- Created On: 05/08/00
-- Modified On: 05/08/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Creates two new primatives that are basically a square donut. Both are
-- created in the panel, and get placed in the scene as editable meshes.
--
-- Warning: you must have the plugin "solidify" installed to run this script,
-- available from http://www.max3d.com/~terralux/software.html
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

my_size = 50

-- Functions

fn create_s_edge =
	(
	Plane length:my_size width:my_size pos:[0,0,0] isSelected:on
	$.lengthsegs = 3
	$.widthsegs = 3
	convertTo $ TriMeshGeometry
	deleteFace $ 9
	deleteFace $ 9
	addmodifier $ (Solidify ())
	$.modifiers[#Solidify].amount = my_size
	convertTo $ TriMeshGeometry
	)

fn create_t_edge =
	(
	newsize = (sqrt(my_size^2 + my_size^2))/2
	newsize2 = newsize/3
	Tube smooth:off sides:4 capsegs:1 heightsegs:1 radius1:newsize2 radius2:newsize height:my_size isSelected:on
	rotate $ (angleaxis -45 [0,0,1])
	addmodifier $ (XForm ())
	set coordsys local
	$.modifiers[#XForm].gizmo.rotation += quat 0 0 0.382683 0.92388
	subobjectLevel = 0
	rotate $ (angleaxis 45 [0,0,1])
	convertTo $ TriMeshGeometry
	)

-- Script

rollout hollowcube_rollout "HollowCube"
	(
	button s_edge "Square Edge" width:110 align:#center toolTip:"Square Edge"
	on s_edge pressed do create_s_edge()

	button t_edge "Trangular Edge" width:110 align:#center toolTip:"Trangular Edge"
	on t_edge pressed do create_t_edge()

	spinner hollowcube_size "Size: " range:[0,9999999,50] type:#worldunits fieldWidth:60 align:#center
	on hollowcube_size changed val do my_size = val
	)

hollowcube_floater = newRolloutFloater "HollowCube v1.00" 170 144
addRollout hollowcube_rollout hollowcube_floater
)
-------------------------------------------------------------------------------
)

MacroScript LightCleaner category:"Soulburn" tooltip:"LightCleaner" Icon:#("Soulburn",22)
(
-------------------------------------------------------------------------------
-- LightCleaner_v100.ms
-- By Neil Blevins (neil@soulburn3d.com)
-- v 1.00
-- Created On: 05/13/00
-- Modified On: 05/13/00
-- tested using Max 3.1
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- What this script does: 
-- Turns on or off various parameters in all selected lights (show attenuation, 
-- show cone, etc). This lets you quickly "clean" your viewport of unneeded 
-- mess when you have lots of lights in your scene.
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
(
-- Variables

-- Functions

fn turn_on =
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"LightCleaner")
	for i = 1 to selection.count do
		(
		if superclassof selection[i] == light then
			(
			selection[i].showNearAtten = true
			selection[i].showFarAtten = true
			if classof selection[i] == targetSpot or classof selection[i] == freeSpot or classof selection[i] == TargetDirectionallight or classof selection[i] == Directionallight then selection[i].showCone = true
			)
		)
	)

fn turn_off =
	(
	if $ == undefined then (MessageBox "Please select at least one object" title:"LightCleaner")
	for i = 1 to selection.count do
		(
		if superclassof selection[i] == light then
			(
			selection[i].showNearAtten = false
			selection[i].showFarAtten = false
			if classof selection[i] == targetSpot or classof selection[i] == freeSpot or classof selection[i] == TargetDirectionallight or classof selection[i] == Directionallight then selection[i].showCone = false
			)
		)
	)

-- Script

rollout lightcleaner_rollout "LightCleaner"
	(
	button button_on "On" width:150 align:#center toolTip:"On"
	button button_off "Off" width:150 align:#center toolTip:"Off"
	on button_on pressed do 
		(
		turn_on ()
		)
	on button_off pressed do 
		(
		turn_off ()
		)
	)

lightcleaner_floater = newRolloutFloater "LightCleaner v1.00" 230 123
addRollout lightcleaner_rollout lightcleaner_floater
)
-------------------------------------------------------------------------------
)